@@ -20,7 +20,7 @@ typedef struct {
   char *name;
   int capacity_full;
 } bat_info;
-  
+
 
 class YApm: public YWindow, public YTimerListener {
 public:
@@ -42,6 +42,7 @@ private:
     void AcpiStr(char *s, bool Tool);
     void SysStr(char *s, bool Tool);
     void PmuStr(char *, const bool);
+    void ApmStr(char *s, bool Tool);
     int ignore_directory_bat_entry(struct dirent *de);
     int ignore_directory_ac_entry(struct dirent *de);
 
@@ -49,6 +50,10 @@ private:
     static YColor *apmFg;
     static ref<YFont> apmFont;
 
+    static YColor *apmColorOnLine;
+    static YColor *apmColorBattery;
+    static YColor *apmColorGraphBg;
+
     // display mode: pmu, acpi or apm info
     enum { APM, ACPI, PMU, SYSFS } mode;
     //number of batteries (for apm == 1)
@@ -63,6 +68,10 @@ private:
     char *acpiACName;
     char *fCurrentState;
 
+    // On line status and charge persent
+    int      acIsOnLine;
+    double   chargeStatus;
+
     void updateState();
 };
 #else
