@@ -53,14 +53,18 @@
 #ifdef HAVE_SCHED_H
 #include <sched.h>
 #endif
-
+#include <dirent.h>
 #include "intl.h"
 
 #if (defined(linux) || defined(HAVE_KSTAT_H)) || defined(HAVE_SYSCTL_CP_TIME)
 
 extern ref<YPixmap> taskbackPixmap;
 
-CPUStatus::CPUStatus(YWindow *aParent): YWindow(aParent) {
+CPUStatus::CPUStatus(YWindow *aParent,
+          bool cpustatusShowRamUsage,
+					bool cpustatusShowSwapUsage,
+					bool cpustatusShowAcpiTemp,
+					bool cpustatusShowCpuFreq): YWindow(aParent) {
     cpu = new int *[taskBarCPUSamples];
 
     for (int a(0); a < taskBarCPUSamples; a++)
@@ -90,6 +94,10 @@ CPUStatus::CPUStatus(YWindow *aParent): YWindow(aParent) {
     last_cpu[IWM_USER] = last_cpu[IWM_NICE] = last_cpu[IWM_SYS] =
     last_cpu[IWM_IDLE] = last_cpu[IWM_INTR] =
     last_cpu[IWM_IOWAIT] = last_cpu[IWM_SOFTIRQ] = 0;
+    ShowRamUsage = cpustatusShowRamUsage;
+    ShowSwapUsage = cpustatusShowSwapUsage;
+    ShowAcpiTemp = cpustatusShowAcpiTemp;
+    ShowCpuFreq = cpustatusShowCpuFreq;
     getStatus();
     updateStatus();
     updateToolTip();
@@ -169,8 +177,8 @@ void CPUStatus::paint(Graphics &g, const YRect &/*r*/) {
                 y -= iowaitbar;
             }
 #if 0
-            msg(_("stat:\tuser = %i, nice = %i, sys = %i, idle = %i"), cpu[i][IWM_USER], cpu[i][IWM_NICE], cpu[i][IWM_SYS], cpu[i][IWM_IDLE]);
-            msg(_("bars:\tuser = %i, nice = %i, sys = %i (h = %i)\n"), userbar, nicebar, sysbar, h);
+            msg("stat:\tuser = %i, nice = %i, sys = %i, idle = %i", cpu[i][IWM_USER], cpu[i][IWM_NICE], cpu[i][IWM_SYS], cpu[i][IWM_IDLE]);
+            msg("bars:\tuser = %i, nice = %i, sys = %i (h = %i)\n", userbar, nicebar, sysbar, h);
 #endif
         }
         if (y > 0) {
@@ -179,10 +187,10 @@ void CPUStatus::paint(Graphics &g, const YRect &/*r*/) {
                 g.drawLine(i, 0, i, y);
             } else {
 #ifdef CONFIG_GRADIENTS
-                ref<YPixbuf> gradient = parent()->getGradient();
+                ref<YImage> gradient = parent()->getGradient();
 
                 if (gradient != null)
-                    g.copyPixbuf(*gradient,
+                    g.drawImage(gradient,
                                  this->x() + i, this->y(), width(), y + 1, i, 0);
                 else
 #endif
@@ -205,19 +213,38 @@ bool CPUStatus::handleTimer(YTimer *t) {
 
 void CPUStatus::updateToolTip() {
 #ifdef linux
-    char load[31];
+    char load[31], ram[31] = "", swap[31] = "", acpitemp[61] = "", cpufreq[31] = "";
     struct sysinfo sys;
     double l1, l5, l15;
 
     sysinfo(&sys);
-    l1 = sys.loads[0] / 65536.0;
-    l5 = sys.loads[1] / 65536.0;
-    l15 = sys.loads[2] / 65536.0;
-    sprintf(load, "%3.2f %3.2f %3.2f, %d",
-            l1, l5, l15, sys.procs);
-    char *loadmsg = strJoin(_("CPU Load: "), load, _(" processes."), NULL);
-    setToolTip(loadmsg);
-    delete [] loadmsg;
+    l1 = (float)sys.loads[0] / 65536.0;
+    l5 = (float)sys.loads[1] / 65536.0;
+    l15 = (float)sys.loads[2] / 65536.0;
+
+    sprintf(load, _("CPU Load: %3.2f %3.2f %3.2f, %d"), l1, l5, l15, sys.procs);
+    if (ShowRamUsage) {
+        float tr =(float)sys.totalram * (float)sys.mem_unit / 1048576.0f;
+        float fr =(float)sys.freeram * (float)sys.mem_unit / 1048576.0f;
+        sprintf(ram, _("\nRam: %5.2f/%.2fM"), tr, fr);
+    }
+    if (ShowSwapUsage) {
+        float ts =(float)sys.totalswap * (float)sys.mem_unit / 1048576.0f;
+        float fs =(float)sys.freeswap * (float)sys.mem_unit / 1048576.0f;
+        sprintf(swap, _("\nSwap: %.2f/%.2fM"), ts, fs);
+    }
+    if (ShowAcpiTemp) {
+        int headlen;
+        sprintf(acpitemp, _("\nACPI Temp:"));
+        headlen = strlen(acpitemp);
+        getAcpiTemp(acpitemp + headlen, (sizeof(acpitemp) - headlen) / sizeof(char));
+    }
+    if (ShowCpuFreq) {
+        sprintf(cpufreq, _("\nCPU Freq: %.3fGHz"), getCpuFreq(0) / 1e6);
+    }
+    char *loadmsg = cstrJoin(load, ram, swap, acpitemp, cpufreq, NULL);
+
+    setToolTip(ustring(loadmsg));
 #elif defined HAVE_GETLOADAVG2
     char load[31]; // enough for "CPU Load: 999.99 999.99 999.99\0"
     double loadavg[3];
@@ -225,7 +252,7 @@ void CPUStatus::updateToolTip() {
         return;
     snprintf(load, sizeof(load), "CPU Load: %3.2f %3.2f %3.2f",
             loadavg[0], loadavg[1], loadavg[2]);
-    char *loadmsg = strJoin(_("CPU Load: "), load, NULL);
+    char *loadmsg = cstrJoin(_("CPU Load: "), load, NULL);
     setToolTip(loadmsg);
     delete [] loadmsg;
 #endif
@@ -253,6 +280,61 @@ void CPUStatus::updateStatus() {
     repaint();
 }
 
+int CPUStatus::getAcpiTemp(char *tempbuf, int buflen) {
+    int retbuflen = 0;
+    char namebuf[64];
+    char buf[64];
+
+    memset(tempbuf, 0, buflen);
+    DIR *dir;
+    if ((dir = opendir("/proc/acpi/thermal_zone")) != NULL) {
+        struct dirent *de;
+
+        while ((de = readdir(dir)) != NULL) {
+            int fd, seglen;
+
+            if (strcmp(de->d_name, ".") == 0 || strcmp(de->d_name, "..") == 0)
+                continue;
+ 
+            sprintf(namebuf, "/proc/acpi/thermal_zone/%s/temperature", de->d_name);
+            fd = open(namebuf, O_RDONLY);
+            if (fd != -1) {
+                int len = read(fd, buf, sizeof(buf) - 1);
+                buf[len - 1] = '\0';
+                seglen = strlen(buf + len - 7);
+                if (retbuflen + seglen >= buflen) {
+                    retbuflen = -retbuflen;
+                    close(fd);
+                    closedir(dir);
+                    break;
+                }
+                retbuflen += seglen;
+                strncat(tempbuf, buf + len - 7, seglen);
+                close(fd);
+            }
+        }
+        closedir(dir);
+    } 
+    return retbuflen;
+}
+
+float CPUStatus::getCpuFreq(unsigned int cpu) {
+    char buf[16], namebuf[64];
+    int fd;
+    float cpufreq = 0;
+
+    sprintf(namebuf, "/sys/devices/system/cpu/cpu%d/cpufreq/scaling_cur_freq", cpu);
+    fd = open(namebuf, O_RDONLY);
+    if (fd != -1) {
+        int len = read(fd, buf, sizeof(buf) - 1);
+        buf[len-1] = '\0';
+        sscanf(buf, "%f", &cpufreq);
+        close(fd);
+    }
+    return(cpufreq);
+}
+
+
 void CPUStatus::getStatus() {
 #ifdef linux
     char *p, buf[4096];
@@ -301,11 +383,11 @@ void CPUStatus::getStatus() {
         case 6: d = IWM_SOFTIRQ; break;
         }
         cur[d] = strtoll(p, &p, 10);
-        cpu[taskBarCPUSamples - 1][d] = cur[d] - last_cpu[d];
+        cpu[taskBarCPUSamples - 1][d] = (int)(cur[d] - last_cpu[d]);
         last_cpu[d] = cur[d];
     }
 #if 0
-    msg(_("cpu: %d %d %d %d %d %d %d"),
+    msg("cpu: %d %d %d %d %d %d %d",
         cpu[taskBarCPUSamples-1][IWM_USER],
         cpu[taskBarCPUSamples-1][IWM_NICE],
         cpu[taskBarCPUSamples-1][IWM_SYS],
@@ -398,7 +480,7 @@ void CPUStatus::getStatus() {
                     cpu_ks[thiscpu] = ks;
                     thiscpu++;
                     if (thiscpu > ncpus) {
-                        warn(_("kstat finds too many cpus: should be %d"),
+                        warn("kstat finds too many cpus: should be %d",
                              ncpus);
                         return;/* FIXME : need err handler? */
                     }
@@ -468,7 +550,7 @@ void CPUStatus::getStatus() {
 #else
     static int mib[] = { 0, 0 };
 #endif
-    
+
     cpu[taskBarCPUSamples - 1][IWM_USER] = 0;
     cpu[taskBarCPUSamples - 1][IWM_NICE] = 0;
     cpu[taskBarCPUSamples - 1][IWM_SYS] = 0;
