@@ -32,7 +32,8 @@ ref<YPixmap> newMailPixmap;
 
 MailCheck::MailCheck(MailBoxStatus *mbx):
     state(IDLE), fMbx(mbx), fLastSize(-1), fLastCount(-1),
-    fLastUnseen(0), fLastCountSize(-1), fLastCountTime(0) {
+    fLastUnseen(0), fLastCountSize(-1), fLastCountTime(0)
+{
     sk.setListener(this);
 }
 
@@ -40,21 +41,27 @@ MailCheck::~MailCheck() {
     sk.close();
 }
 
-void MailCheck::setURL(char const * url) {
-    char const * validURL(*url == '/' ? strJoin("file://", url, NULL) : url);
+void MailCheck::setURL(ustring url) {
+    if (url.startsWith(mstring("/")))
+        url = url.insert(0, mstring("file://"));
 
-    if ((fURL = validURL).scheme()) {
-        if (!(strcmp(fURL.scheme(), "pop3") &&
-              strcmp(fURL.scheme(), "imap"))) {
-            protocol = (*fURL.scheme() == 'i' ? IMAP : POP3);
+    fURL.init(new YURL(url));
+    if (fURL != null && fURL->scheme() != null) {
+        if (fURL->scheme().equals(mstring("pop3")) ||
+            fURL->scheme().equals(mstring("imap")))
+        {
+            if (fURL->scheme().charAt(0) == 'i')
+                protocol = IMAP;
+            else
+                protocol = POP3;
 
             server_addr.sin_family = AF_INET;
             server_addr.sin_port =
-                htons(fURL.port() ? atoi(fURL.port())
+                htons(fURL->port() != null? atoi(cstring(fURL->port()).c_str())
                       : (protocol == IMAP ? 143 : 110));
 
-            if (fURL.host()) { /// !!! fix, need nonblocking resolve
-                struct hostent const * host(gethostbyname(fURL.host()));
+            if (fURL->host() != null) { /// !!! fix, need nonblocking resolve
+                struct hostent const * host(gethostbyname(cstring(fURL->host()).c_str()));
 
                 if (host)
                     memcpy(&server_addr.sin_addr,
@@ -64,18 +71,16 @@ void MailCheck::setURL(char const * url) {
                     state = ERROR;
             } else
                 server_addr.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
-        } else if (!strcmp(fURL.scheme(), "file"))
+        } else if (!strcmp(cstring(fURL->scheme()).c_str(), "file"))
             protocol = LOCALFILE;
         else
-            warn(_("Invalid mailbox protocol: \"%s\""), fURL.scheme());
+            warn(_("Invalid mailbox protocol: \"%s\""), cstring(fURL->scheme()).c_str());
     } else
-        warn(_("Invalid mailbox path: \"%s\""), url);
-
-    if (validURL != url) delete[] validURL;
+        warn(_("Invalid mailbox path: \"%s\""), cstring(url).c_str());
 }
 
 void MailCheck::countMessages() {
-    int fd = open(fURL.path(), O_RDONLY);
+    int fd = open(cstring(fURL->path()).c_str(), O_RDONLY);
     int mails = 0;
 
     if (fd != -1) {
@@ -115,12 +120,12 @@ void MailCheck::startCheck() {
     if (protocol == LOCALFILE) {
         struct stat st;
         //MailBoxStatus::MailBoxState fNewState = fState;
-        if (fURL.path() == 0)
+        if (fURL->path() == null)
             return;
 
         if (!countMailMessages)
             fLastCount = -1;
-        if (stat(fURL.path(), &st) == -1) {
+        if (stat(cstring(fURL->path()).c_str(), &st) == -1) {
             fMbx->mailChecked(MailBoxStatus::mbxNoMail, 0);
             fLastCount = 0;
             fLastSize = 0;
@@ -212,13 +217,13 @@ void MailCheck::socketDataRead(char *buf, int len) {
         }
         if (state == WAIT_READY) {
             MSG(("pop3: ready"));
-            char * user(strJoin("USER ", fURL.user(), "\r\n", NULL));
+            char * user(cstrJoin("USER ", cstring(fURL->user()).c_str(), "\r\n", NULL));
             sk.write(user, strlen(user));
             state = WAIT_USER;
             delete[] user;
         } else if (state == WAIT_USER) {
             MSG(("pop3: login"));
-            char * pass(strJoin("PASS ", fURL.password(), "\r\n", NULL));
+            char * pass(cstrJoin("PASS ", cstring(fURL->password()).c_str(), "\r\n", NULL));
             sk.write(pass, strlen(pass));
             state = WAIT_PASS;
             delete[] pass;
@@ -258,17 +263,17 @@ void MailCheck::socketDataRead(char *buf, int len) {
     } else if (protocol == IMAP) {
         if (state == WAIT_READY) {
             MSG(("imap: login"));
-            char * login(strJoin("0000 LOGIN ",
-                                 fURL.user(), " ",
-                                 fURL.password(), "\r\n", NULL));
+            char * login(cstrJoin("0000 LOGIN ",
+                                  cstring(fURL->user()).c_str(), " ",
+                                  cstring(fURL->password()).c_str(), "\r\n", NULL));
             sk.write(login, strlen(login));
             state = WAIT_USER;
             delete[] login;
         } else if (state == WAIT_USER) {
             MSG(("imap: status"));
-            char * status(strJoin("0001 STATUS ",
-                                  fURL.path() ? fURL.path() + 1 : "INBOX",
-                                  " (MESSAGES)\r\n", NULL));
+            char * status(cstrJoin("0001 STATUS ",
+                                   (fURL->path() == null || fURL->path().equals("/")) ? "INBOX" : cstring(fURL->path()).c_str() + 1,
+                                   " (MESSAGES)\r\n", NULL));
             sk.write(status, strlen(status));
             state = WAIT_STAT;
             delete[] status;
@@ -306,8 +311,8 @@ void MailCheck::socketDataRead(char *buf, int len) {
     sk.read(bf, sizeof(bf));
 }
 
-MailBoxStatus::MailBoxStatus(const char *mailbox, YWindow *aParent): 
-YWindow(aParent), fMailBox(newstr(mailbox)), check(this)
+MailBoxStatus::MailBoxStatus(mstring mailbox, YWindow *aParent):
+YWindow(aParent), fMailBox(mailbox), check(this)
 {
     if (taskBarBg == 0) {
         taskBarBg = new YColor(clrDefaultTaskBar);
@@ -316,8 +321,9 @@ YWindow(aParent), fMailBox(newstr(mailbox)), check(this)
     setSize(16, 16);
     fMailboxCheckTimer = 0;
     fState = mbxNoMail;
-    if (fMailBox) {
-        MSG((_("Using MailBox \"%s\"\n"), fMailBox));
+    if (fMailBox != null) {
+        cstring cs(fMailBox);
+        MSG((_("Using MailBox \"%s\"\n"), cs.c_str()));
         check.setURL(fMailBox);
 
         fMailboxCheckTimer = new YTimer(mailCheckDelay * 1000);
@@ -335,7 +341,6 @@ MailBoxStatus::~MailBoxStatus() {
         fMailboxCheckTimer->setTimerListener(0);
     }
     delete fMailboxCheckTimer; fMailboxCheckTimer = 0;
-    delete [] fMailBox; fMailBox = 0;
 }
 
 void MailBoxStatus::paint(Graphics &g, const YRect &/*r*/) {
@@ -357,13 +362,13 @@ void MailBoxStatus::paint(Graphics &g, const YRect &/*r*/) {
         pixmap = errMailPixmap;
         break;
     }
-    
+
     if (pixmap == null || pixmap->mask()) {
 #ifdef CONFIG_GRADIENTS
-        ref<YPixbuf> gradient = parent()->getGradient();
+        ref<YImage> gradient = parent()->getGradient();
 
         if (gradient != null)
-            g.copyPixbuf(*gradient, x(), y(), width(), height(), 0, 0);
+            g.drawImage(gradient, x(), y(), width(), height(), 0, 0);
         else
 #endif
             if (taskbackPixmap != null)
@@ -428,17 +433,15 @@ void MailBoxStatus::mailChecked(MailBoxState mst, long count) {
     if (fState == mbxError)
         setToolTip(_("Error checking mailbox."));
     else {
-        char s[128];
+        char s[128] = "";
         if (count != -1) {
             sprintf(s,
                     count == 1 ?
                     _("%ld mail message.") :
                     _("%ld mail messages."), // too hard to do properly
                     count);
-            setToolTip(s);
-        } else {
-            setToolTip(0);
         }
+        setToolTip(s);
     }
 }
 
