@@ -39,7 +39,7 @@ public:
     MailCheck(MailBoxStatus *mbx);
     virtual ~MailCheck();
 
-    void setURL(const char *url);
+    void setURL(ustring url);
     void startCheck();
 
     virtual void socketConnected();
@@ -51,7 +51,7 @@ private:
     YSocket sk;
     char bf[512];
     unsigned int got;
-    YURL fURL;
+    ref<YURL> fURL;
     MailBoxStatus *fMbx;
     long fLastSize;
     long fLastCount;
@@ -76,7 +76,7 @@ public:
         mbxError
     };
     
-    MailBoxStatus(const char *mailBox, YWindow *aParent = 0);
+    MailBoxStatus(mstring mailBox, YWindow *aParent = 0);
     virtual ~MailBoxStatus();
 
     virtual void paint(Graphics &g, const YRect &r);
@@ -89,7 +89,7 @@ public:
     
     virtual bool handleTimer(YTimer *t);
 private:
-    char *fMailBox;
+    mstring fMailBox;
     MailBoxState fState;
     MailCheck check;
     YTimer *fMailboxCheckTimer;
