@@ -1,5 +1,6 @@
 #define defgMouseWinMove                XK_Pointer_Button1, kfAlt, "Alt+Pointer_Button1"
 #define defgMouseWinSize                XK_Pointer_Button3, kfAlt, "Alt+Pointer_Button3"
+#define defgMouseWinRaise               XK_Pointer_Button1, kfCtrl+kfAlt, "Ctrl+Alt+Pointer_Button1"
 
 #define defgKeyWinRaise                 XK_F1, kfAlt, "Alt+F1"
 #define defgKeyWinOccupyAll             XK_F2, kfAlt, "Alt+F2"
@@ -116,6 +117,7 @@
 
 DEF_WMKEY(gMouseWinMove);
 DEF_WMKEY(gMouseWinSize);
+DEF_WMKEY(gMouseWinRaise);
 
 DEF_WMKEY(gKeyWinRaise);
 DEF_WMKEY(gKeyWinOccupyAll);
