@@ -302,6 +302,10 @@ node *parse(FILE *fp, int flags, node *parent, node *&nextsub, node::node_type &
                 buf[len-1] = 0;
 
                 node::node_type type = get_type(buf);
+                if (buf != 0) {
+                    free(buf);
+                    buf = 0;
+                }
 
 #if 1
                 if (type == node::paragraph ||
@@ -335,6 +339,11 @@ node *parse(FILE *fp, int flags, node *parent, node *&nextsub, node::node_type &
                 node::node_type type = get_type(buf);
                 node *n = new node(type);
 
+                if (buf != 0) {
+                    free(buf);
+                    buf = 0;
+                }
+
                 if (n == 0)
                     break;
 
@@ -504,6 +513,11 @@ node *parse(FILE *fp, int flags, node *parent, node *&nextsub, node::node_type &
                     node *n = new node(node::text);
                     n->txt = buf;
                     l = add(&f, l, n);
+                    buf = 0;
+                }
+                if (buf != 0) {
+                   free(buf); 
+                   buf = 0;
                 }
                 continue;
             }
@@ -533,6 +547,20 @@ public:
         nextItem->setEnabled(false);
         contentsItem->setEnabled(false);
 
+        if (nextURL != 0) {
+            delete[] prevURL;
+            nextURL = 0;
+        }
+        if (nextURL != 0) {
+            delete[] prevURL;
+            nextURL = 0;
+        }
+        if (contentsURL != 0) {
+            delete[] contentsURL;
+            contentsURL = 0;
+        }
+
+
         find_link(fRoot);
     }
 
@@ -610,9 +638,9 @@ public:
             listener->activateURL(contentsURL);
     }
 
-    virtual void configure(const YRect &r, const bool resized) {
-        YWindow::configure(r, resized);
-        if (resized) layout();
+    virtual void configure(const YRect &r) {
+        YWindow::configure(r);
+        layout();
     }
 
     bool handleKey(const XKeyEvent &key);
@@ -686,11 +714,11 @@ HTextView::HTextView(HTListener *fL, YScrollView *v, YWindow *parent):
     menu->addItem(_("Back"), 0, _("Alt+Left"), actionNone)->setEnabled(false);
     menu->addItem(_("Forward"), 0, _("Alt+Right"), actionNone)->setEnabled(false);
     menu->addSeparator();
-    prevItem = menu->addItem(_("Previous"), 0, "", actionPrev);
-    nextItem = menu->addItem(_("Next"), 0, "", actionNext);
+    prevItem = menu->addItem(_("Previous"), 0, null, actionPrev);
+    nextItem = menu->addItem(_("Next"), 0, null, actionNext);
     menu->addSeparator();
-    contentsItem = menu->addItem(_("Contents"), 0, "", actionContents);
-    menu->addItem(_("Index"), 0, "", actionNone)->setEnabled(false);
+    contentsItem = menu->addItem(_("Contents"), 0, null, actionContents);
+    menu->addItem(_("Index"), 0, null, actionNone)->setEnabled(false);
     menu->addSeparator();
     menu->addItem(_("Close"), 0, _("Ctrl+Q"), actionClose);
 }
@@ -1167,6 +1195,12 @@ void HTextView::handleButton(const XButtonEvent &button) {
 class FileView: public YWindow, public HTListener {
 public:
     FileView(char *path);
+    ~FileView() {
+        if (fPath != 0) {
+            delete[] fPath;
+            fPath = 0;
+        }
+    }
 
     void loadFile();
 
@@ -1202,9 +1236,9 @@ public:
 #endif
     }
 
-    virtual void configure(const YRect &r, const bool resized) {
-        YWindow::configure(r, resized);
-        if (resized) scroll->setGeometry(YRect(0, 0, r.width(), r.height()));
+    virtual void configure(const YRect &r) {
+        YWindow::configure(r);
+        scroll->setGeometry(YRect(0, 0, r.width(), r.height()));
     }
 
     virtual void handleClose() {
@@ -1235,9 +1269,9 @@ FileView::FileView(char *path) {
     setTitle(fPath);
     setClassHint("browser", "IceHelp");
 
-    YIcon *file_icon = YIcon::getIcon("file");
-    small_icon.init(new YPixmap(*file_icon->small()));
-    large_icon.init(new YPixmap(*file_icon->large()));
+    ref<YIcon> file_icon = YIcon::getIcon("file");
+    small_icon = YPixmap::createFromImage(file_icon->small());
+    large_icon = YPixmap::createFromImage(file_icon->large());
 
     Pixmap icons[4] = {
         small_icon->pixmap(), small_icon->mask(),
