@@ -23,8 +23,8 @@ char const *ApplicationName = "iceicon";
 class ObjectList;
 class ObjectIconView;
 
-YIcon *folder = 0;
-YIcon *file = 0;
+ref<YIcon> folder;
+ref<YIcon> file;
 
 class YScrollView;
 
@@ -39,7 +39,7 @@ public:
     void setPrev(YIconItem *prev);
 
     virtual const char *getText();
-    virtual YIcon *getIcon();
+    virtual ref<YIcon> getIcon();
 
     int x, y, w, h;
     int ix;
@@ -134,7 +134,7 @@ void YIconItem::setPrev(YIconItem *prev) {
 
 
 const char *YIconItem::getText() { return 0; }
-YIcon *YIconItem::getIcon() { return 0; }
+ref<YIcon> YIconItem::getIcon() { return null; }
 
 int YIconView::addItem(YIconItem *item) {
     PRECONDITION(item->getPrev() == 0);
@@ -240,7 +240,7 @@ bool YIconView::layout() {
         const char *text = icon->getText();
         int tw = font->textWidth(text) + 4;
         int th = fontHeight + 2;
-        ref<YIconImage> icn = icon->getIcon()->large();
+        ref<YImage> icn = icon->getIcon()->large();
         int iw = icn->width() + 4;
         int ih = icn->height() + 4;
 
@@ -304,7 +304,7 @@ void YIconView::paint(Graphics &g, const YRect &r) {
             break;
 
         const char *text = icon->getText();
-        ref<YIconImage> icn = icon->getIcon()->large();
+        ref<YImage> icn = icon->getIcon()->large();
 
         g.drawImage(icn,
                      icon->x - fOffsetX + icon->ix + 2,
@@ -400,13 +400,13 @@ public:
         char *path = getLocation();
         if (stat(path, &sb) == 0 && S_ISDIR(sb.st_mode))
             fFolder = true;
-        delete path;
+        delete[] path;
     }
-    virtual ~ObjectIconItem() { delete fName; fName = 0; }
+    virtual ~ObjectIconItem() { delete[] fName; fName = 0; }
 
     virtual const char *getText() { return fName; }
     bool isFolder() { return fFolder; }
-    virtual YIcon *getIcon() { return isFolder() ? folder : file; }
+    virtual ref<YIcon> getIcon() { return isFolder() ? folder : file; }
 
 
     char *getLocation();
