@@ -15,6 +15,10 @@
 #include <libgen.h>
 #endif
 
+#ifdef linux
+#include <execinfo.h>
+#endif
+
 extern char const *ApplicationName;
 
 #ifdef DEBUG
@@ -191,7 +195,7 @@ void logEvent(const XEvent &xev) {
     case PropertyNotify:
         break;
 #endif
-#if 0
+#if 1
     case ButtonPress:
     case ButtonRelease:
         msg("window=0x%lX: %s root=0x%lX, subwindow=0x%lX, time=%ld, (%d:%d %d:%d) state=0x%X detail=0x%X same_screen=%s",
@@ -227,7 +231,7 @@ void logEvent(const XEvent &xev) {
     case MotionNotify:
         break;
 #endif
-#if 0
+#if 1
     case EnterNotify:
     case LeaveNotify:
         msg("window=0x%lX: %s serial=%10d root=0x%lX, subwindow=0x%lX, time=%ld, (%d:%d %d:%d) mode=%d detail=%d same_screen=%s, focus=%s state=0x%X",
@@ -311,6 +315,7 @@ void precondition(char const *msg, ...) {
     va_end(ap);
     fputs("\n", stderr);
 
+    show_backtrace();
     *(char *)0 = 0x42;
 }
 
@@ -336,7 +341,7 @@ void msg(char const *msg, ...) {
     fputs("\n", stderr);
 }
 
-char *strJoin(char const *str, ...) {
+char *cstrJoin(char const *str, ...) {
     va_list ap;
     char const *s;
     char *res, *p;
@@ -448,9 +453,10 @@ char const * strnxt(const char * str, const char * delim) {
     str+= strcspn(str, delim);
     str+= strspn(str, delim);
     return str;
-
 }
 
+#if 0
+
 /*
  *      Counts the tokens separated by delim
  */
@@ -466,6 +472,7 @@ unsigned strtoken(const char * str, const char * delim) {
 
     return count;
 }
+#endif
 
 #if 1
 const char *my_basename(const char *path) {
@@ -478,15 +485,32 @@ const char *my_basename(const char *path) {
 }
 #endif
 
+#if 0
 bool strequal(const char *a, const char *b) {
     return a ? b && !strcmp(a, b) : !b;
 }
+#endif
 
+#if 0
 int strnullcmp(const char *a, const char *b) {
     return a ? (b ? strcmp(a, b) : 1) : (b ? -1 : 0);
 }
+#endif
 
 bool isreg(char const *path) {
     struct stat sb;
     return (stat(path, &sb) == 0 && S_ISREG(sb.st_mode));
 }
+
+void show_backtrace() {
+#ifdef linux
+    const char head[] = "\nbacktrace:\n";
+    const char tail[] = "end\n";
+    void *array[20];
+
+    write(2, head, sizeof(head));
+    int size = backtrace(array, sizeof array / sizeof array[0]);
+    backtrace_symbols_fd(array, size, 2);
+    write(2, tail, sizeof(tail));
+#endif
+}
