@@ -18,6 +18,9 @@
 
 #include "intl.h"
 
+#include "wmtaskbar.h"
+#include "aworkspaces.h"
+
 #include <stdio.h>
 
 void YFrameWindow::snapTo(int &wx, int &wy,
@@ -317,7 +320,7 @@ void YFrameWindow::handleMoveMouse(const XMotionEvent &motion, int &newX, int &n
     int mouseX = motion.x_root;
     int mouseY = motion.y_root;
 
-    constrainMouseToWorkspace(mouseX, mouseY);
+    //constrainMouseToWorkspace(mouseX, mouseY);
 
     newX = mouseX - buttonDownX;
     newY = mouseY - buttonDownY;
@@ -382,7 +385,7 @@ void YFrameWindow::handleResizeMouse(const XMotionEvent &motion,
     int mouseX = motion.x_root;
     int mouseY = motion.y_root;
 
-    constrainMouseToWorkspace(mouseX, mouseY);
+//    constrainMouseToWorkspace(mouseX, mouseY);
 
     if (grabX == -1) {
         newX = mouseX - buttonDownX;
@@ -967,10 +970,11 @@ void YFrameWindow::startMoveSize(int doMove, int byMouse,
     }
 
     XSync(xapp->display(), False);
-    if (!xapp->grabEvents(this, grabPointer,
-                         ButtonPressMask |
-                         ButtonReleaseMask |
-                         PointerMotionMask))
+    if (!xapp->grabEvents(this,
+                          grabPointer,
+                          ButtonPressMask |
+                          ButtonReleaseMask |
+                          PointerMotionMask))
     {
         return ;
     }
@@ -1009,6 +1013,12 @@ void YFrameWindow::endMoveSize() {
     sizingWindow = 0;
 
     manager->setWorkAreaMoveWindows(false);
+
+#ifdef CONFIG_TASKBAR
+    if (taskBar && taskBar->workspacesPane()) {
+        taskBar->workspacesPane()->repaint();
+    }
+#endif
 }
 
 void YFrameWindow::handleBeginDrag(const XButtonEvent &down, const XMotionEvent &motion) {
