@@ -5,7 +5,7 @@
 
 #if defined(CONFIG_I18N) || 1 // maybe not such a good idea
 XIV(bool, prettyClock,                          false)
-#else 
+#else
 XIV(bool, prettyClock,                          true)
 #endif
 XIV(bool, rolloverTitleButtons,                 false)
@@ -45,25 +45,25 @@ XSV(const char *, titleButtonsSupported,        "xmis");
 XSV(const char *, themeAuthor,                  0)
 XSV(const char *, themeDescription,             0)
 
-XFV(const char *, titleFontName,                FONT(120), "sans-serif,Bitstream Vera Serif:size=12")
-XFV(const char *, menuFontName,                 BOLDFONT(100), "sans-serif,Bitstream Vera Serif:size=10:bold")
-XFV(const char *, statusFontName,               BOLDTTFONT(120), "monospace,Bitstream Vera Sans Mono:size=12:bold")
-XFV(const char *, switchFontName,               BOLDTTFONT(120), "monospace,Bitstream Vera Sans Mono:size=12:bold")
-XFV(const char *, normalButtonFontName,         FONT(120), "sans-serif,Bitstream Vera Serif:size=12")
-XFV(const char *, activeButtonFontName,         BOLDFONT(120), "sans-serif,Bitstream Vera Serif:size=12:bold")
+XFV(const char *, titleFontName,                FONT(120), "sans-serif:size=12")
+XFV(const char *, menuFontName,                 BOLDFONT(100), "sans-serif:size=10:bold")
+XFV(const char *, statusFontName,               BOLDTTFONT(120), "monospace:size=12:bold")
+XFV(const char *, switchFontName,               BOLDTTFONT(120), "monospace:size=12:bold")
+XFV(const char *, normalButtonFontName,         FONT(120), "sans-serif:size=12")
+XFV(const char *, activeButtonFontName,         BOLDFONT(120), "sans-serif:size=12:bold")
 #ifdef CONFIG_TASKBAR
-XFV(const char *, normalTaskBarFontName,        FONT(120), "sans-serif,Bitstream Vera Serif:size=12")
-XFV(const char *, activeTaskBarFontName,        BOLDFONT(120), "sans-serif,Bitstream Vera Serif:size=12:bold")
-XFV(const char *, toolButtonFontName,           FONT(120), "sans-serif,Bitstream Vera Serif:size=12")
-XFV(const char *, normalWorkspaceFontName,      FONT(120), "sans-serif,Bitstream Vera Serif:size=12")
-XFV(const char *, activeWorkspaceFontName,      FONT(120), "sans-serif,Bitstream Vera Serif:size=12")
+XFV(const char *, normalTaskBarFontName,        FONT(120), "sans-serif:size=12")
+XFV(const char *, activeTaskBarFontName,        BOLDFONT(120), "sans-serif:size=12:bold")
+XFV(const char *, toolButtonFontName,           FONT(120), "sans-serif:size=12")
+XFV(const char *, normalWorkspaceFontName,      FONT(120), "sans-serif:size=12")
+XFV(const char *, activeWorkspaceFontName,      FONT(120), "sans-serif:size=12")
 #endif
-XFV(const char *, minimizedWindowFontName,      FONT(120), "sans-serif,Bitstream Vera Serif:size=12")
-XFV(const char *, listBoxFontName,              FONT(120), "sans-serif,Bitstream Vera Serif:size=12")
-XFV(const char *, labelFontName,                FONT(140), "sans-serif,Bitstream Vera Serif:size=12")
-XFV(const char *, clockFontName,                TTFONT(140), "monospace,Bitstream Vera Sans Mono:size=12")
-XFV(const char *, apmFontName,                  TTFONT(140), "monospace,Bitstream Vera Sans Mono:size=12")
-XFV(const char *, inputFontName,                TTFONT(140), "monospace,Bitstream Vera Sans Mono:size=12")
+XFV(const char *, minimizedWindowFontName,      FONT(120), "sans-serif:size=12")
+XFV(const char *, listBoxFontName,              FONT(120), "sans-serif:size=12")
+XFV(const char *, labelFontName,                FONT(140), "sans-serif:size=12")
+XFV(const char *, clockFontName,                TTFONT(140), "monospace:size=12")
+XFV(const char *, apmFontName,                  TTFONT(140), "monospace:size=12")
+XFV(const char *, inputFontName,                TTFONT(140), "monospace:size=12")
 
 XSV(const char *, clrDialog,                    "rgb:C0/C0/C0")
 XSV(const char *, clrActiveBorder,              "rgb:C0/C0/C0")
@@ -127,6 +127,9 @@ XSV(const char *, clrClock,                     "rgb:00/00/00")
 XSV(const char *, clrClockText,                 "rgb:00/FF/00")
 XSV(const char *, clrApm,                       "rgb:00/00/00")
 XSV(const char *, clrApmText,                   "rgb:00/FF/00")
+XSV(const char *, clrApmBat,                    "rgb:FF/FF/00") // hatred: Yellow
+XSV(const char *, clrApmLine,                   "rgb:00/FF/00") // hatred: Green
+XSV(const char *, clrApmGraphBg,                "rgb:00/00/00") // hatred: Black
 XSV(const char *, clrInput,                     "rgb:FF/FF/FF")
 XSV(const char *, clrInputText,                 "rgb:00/00/00")
 XSV(const char *, clrInputSelection,            "rgb:80/80/80")
@@ -256,7 +259,7 @@ cfoption icewm_themable_preferences[] = {
 
     OSV("ColorMoveSizeStatus",                  &clrMoveSizeStatus,             "Background of move/resize status window"),
     OSV("ColorMoveSizeStatusText",              &clrMoveSizeStatusText,         "Textcolor of move/resize status window"),
-    
+
     OSV("ColorQuickSwitch",                     &clrQuickSwitch,                "Background of the quick switch window"),
     OSV("ColorQuickSwitchText",                 &clrQuickSwitchText,            "Textcolor in the quick switch window"),
     OSV("ColorQuickSwitchActive",               &clrQuickSwitchActive,          "Rectangle arround the active icon in the quick switch window"),
@@ -296,11 +299,14 @@ cfoption icewm_themable_preferences[] = {
 #ifdef CONFIG_APPLET_CLOCK
     OSV("ColorClock",                           &clrClock,                      "Background of non-LCD clock, leave empty to force transparency"),
     OSV("ColorClockText",                       &clrClockText,                  "Background of non-LCD monitor"),
-#endif    
+#endif
 #ifdef CONFIG_APPLET_APM
     OSV("ColorApm",                             &clrApm,                        "Background of APM monitor, leave empty to force transparency"),
     OSV("ColorApmText",                         &clrApmText,                    "Textcolor of APM monitor"),
-#endif    
+    OSV("ColorApmBattary",                      &clrApmBat,                     "Color of APM monitor in battary mode"), // hatred
+    OSV("ColorApmLine",                         &clrApmLine,                    "Color of APM monitor in line mode"),    // hatred
+    OSV("ColorApmGraphBg",                      &clrApmGraphBg,                 "Background color for graph mode"),      // hatred
+#endif
 #ifdef CONFIG_APPLET_CPU_STATUS
     OSV("ColorCPUStatusUser",                   &clrCpuUser,                    "User load on the CPU monitor"),
     OSV("ColorCPUStatusSystem",                 &clrCpuSys,                     "System load on the CPU monitor"),
@@ -309,7 +315,7 @@ cfoption icewm_themable_preferences[] = {
     OSV("ColorCPUStatusSoftIrq",                &clrCpuSoftIrq,                 "Soft Interrupts on the CPU monitor"),
     OSV("ColorCPUStatusNice",                   &clrCpuNice,                    "Nice load on the CPU monitor"),
     OSV("ColorCPUStatusIdle",                   &clrCpuIdle,                    "Idle (non) load on the CPU monitor, leave empty to force transparency"),
-#endif    
+#endif
 #ifdef CONFIG_APPLET_NET_STATUS
     OSV("ColorNetSend",                         &clrNetSend,                    "Outgoing load on the network monitor"),
     OSV("ColorNetReceive",                      &clrNetReceive,                 "Incoming load on the network monitor"),
