@@ -40,6 +40,7 @@ YAction *actionLogout(0);
 YAction *actionCancelLogout(0);
 YAction *actionLock(0);
 YAction *actionReboot(0);
+YAction *actionRestart(0);
 YAction *actionShutdown(0);
 YAction *actionRefresh(0);
 YAction *actionCollapseTaskbar(0);
@@ -92,6 +93,7 @@ void initActions() {
     actionCancelLogout = new YAction();
     actionLock = new YAction();
     actionReboot = new YAction();
+    actionRestart = new YAction();
     actionShutdown = new YAction();
     actionRefresh = new YAction();
     actionCollapseTaskbar = new YAction();
