@@ -31,7 +31,7 @@
 #include "themes.h"
 #include "sysdep.h"
 #include "prefs.h"
-#include "ypixbuf.h"
+#include "yimage.h"
 #include "ylocale.h"
 #include <stdio.h>
 #include <sys/resource.h>
@@ -39,6 +39,7 @@
 #include "yprefs.h"
 #include "yicon.h"
 #include "prefs.h"
+#include "upath.h"
 
 #include "intl.h"
 
@@ -50,7 +51,7 @@ static bool restart(false);
 YWMApp *wmapp(NULL);
 YWindowManager *manager(NULL);
 
-char *keysFile(NULL);
+upath keysFile;
 
 Atom XA_IcewmWinOptHint(None);
 Atom XA_ICEWM_FONT_PATH(None);
@@ -97,7 +98,7 @@ static char *overrideTheme(NULL);
 
 char *configArg(NULL);
 
-YIcon *defaultAppIcon = 0;
+ref<YIcon> defaultAppIcon;
 bool replace_wm = false;
 
 static Window registerProtocols1() {
@@ -293,6 +294,16 @@ static void initAtoms() {
 static void initFontPath() {
 #ifndef LITE
     if (themeName) { // =================== find the current theme directory ===
+        upath themesFile(themeName);
+        upath themesDir = themesFile.parent();
+        upath fonts_dirFile = themesDir.child("fonts.dir");
+        upath fonts_dirPath = YApplication::findConfigFile(fonts_dirFile);
+        upath fonts_dirDir(null);
+
+        if (fonts_dirPath != null)
+            upath fonts_dirDir = fonts_dirPath.parent();
+
+#if 0
         char themeSubdir[PATH_MAX];
         strncpy(themeSubdir, themeName, sizeof(themeSubdir) - 1);
         themeSubdir[sizeof(themeSubdir) - 1] = '\0';
@@ -301,19 +312,21 @@ static void initFontPath() {
         if (strfn) *strfn = '\0';
 
         // ================================ is there a file named fonts.dir? ===
-        char * fontsdir;
+        upath fontsdir;
 
         if (*themeName == '/')
-            fontsdir = strJoin(themeSubdir, "/fonts.dir", NULL);
+            fontsdir = cstrJoin(themeSubdir, "/fonts.dir", NULL);
         else {
-            strfn = strJoin("themes/", themeSubdir, "/fonts.dir", NULL);
+            strfn = cstrJoin("themes/", themeSubdir, "/fonts.dir", NULL);
             fontsdir = (app->findConfigFile(strfn));
             delete[] strfn;
         }
+#endif
+
+        if (fonts_dirDir != null) { // =========================== build a new font path ===
+            cstring dir(fonts_dirDir.path());
+            const char *fontsdir = dir.c_str();
 
-        if (fontsdir) { // =========================== build a new font path ===
-            strfn = strrchr(fontsdir, '/');
-            if (strfn) *strfn = '\0';
 #if CONFIG_XFREETYPE >= 2
             MSG(("font dir add %s", fontsdir));
             FcConfigAppFontAddDir(0, (FcChar8 *)fontsdir);
@@ -402,13 +415,13 @@ static void initPointers() {
 }
 
 #ifdef CONFIG_GRADIENTS
-static bool loadGradient(YResourcePaths const & paths,
-                         char const * tag, ref<YPixbuf> & pixbuf,
+static bool loadGradient(ref<YResourcePaths> paths,
+                         char const * tag, ref<YImage> &gradient,
                          char const * name, char const * path = NULL)
 {
     if (!strcmp(tag, name)) {
-        if (pixbuf == null)
-            pixbuf = paths.loadPixbuf(path, name, false);
+        if (gradient == null)
+            gradient = paths->loadImage(path, name /*, false */);
         else
             warn(_("Multiple references for gradient \"%s\""), name);
 
@@ -420,7 +433,7 @@ static bool loadGradient(YResourcePaths const & paths,
 #endif
 
 static void initPixmaps() {
-    YResourcePaths paths("", true);
+    ref<YResourcePaths> paths = YResourcePaths::subdirs(null, true);
 
 #ifdef CONFIG_LOOK_PIXMAP
     if (wmLook == lookPixmap || wmLook == lookMetal || wmLook == lookGtk || wmLook == lookFlat) {
@@ -495,110 +508,110 @@ static void initPixmaps() {
         }
 #endif
 
-           closePixmap[0] = paths.loadPixmap(0, "closeI.xpm");
-           depthPixmap[0] = paths.loadPixmap(0, "depthI.xpm");
-        maximizePixmap[0] = paths.loadPixmap(0, "maximizeI.xpm");
-        minimizePixmap[0] = paths.loadPixmap(0, "minimizeI.xpm");
-         restorePixmap[0] = paths.loadPixmap(0, "restoreI.xpm");
-            hidePixmap[0] = paths.loadPixmap(0, "hideI.xpm");
-          rollupPixmap[0] = paths.loadPixmap(0, "rollupI.xpm");
-        rolldownPixmap[0] = paths.loadPixmap(0, "rolldownI.xpm");
-           closePixmap[1] = paths.loadPixmap(0, "closeA.xpm");
-           depthPixmap[1] = paths.loadPixmap(0, "depthA.xpm");
-        maximizePixmap[1] = paths.loadPixmap(0, "maximizeA.xpm");
-        minimizePixmap[1] = paths.loadPixmap(0, "minimizeA.xpm");
-         restorePixmap[1] = paths.loadPixmap(0, "restoreA.xpm");
-            hidePixmap[1] = paths.loadPixmap(0, "hideA.xpm");
-          rollupPixmap[1] = paths.loadPixmap(0, "rollupA.xpm");
-        rolldownPixmap[1] = paths.loadPixmap(0, "rolldownA.xpm");
+           closePixmap[0] = paths->loadPixmap(0, "closeI.xpm");
+           depthPixmap[0] = paths->loadPixmap(0, "depthI.xpm");
+        maximizePixmap[0] = paths->loadPixmap(0, "maximizeI.xpm");
+        minimizePixmap[0] = paths->loadPixmap(0, "minimizeI.xpm");
+         restorePixmap[0] = paths->loadPixmap(0, "restoreI.xpm");
+            hidePixmap[0] = paths->loadPixmap(0, "hideI.xpm");
+          rollupPixmap[0] = paths->loadPixmap(0, "rollupI.xpm");
+        rolldownPixmap[0] = paths->loadPixmap(0, "rolldownI.xpm");
+           closePixmap[1] = paths->loadPixmap(0, "closeA.xpm");
+           depthPixmap[1] = paths->loadPixmap(0, "depthA.xpm");
+        maximizePixmap[1] = paths->loadPixmap(0, "maximizeA.xpm");
+        minimizePixmap[1] = paths->loadPixmap(0, "minimizeA.xpm");
+         restorePixmap[1] = paths->loadPixmap(0, "restoreA.xpm");
+            hidePixmap[1] = paths->loadPixmap(0, "hideA.xpm");
+          rollupPixmap[1] = paths->loadPixmap(0, "rollupA.xpm");
+        rolldownPixmap[1] = paths->loadPixmap(0, "rolldownA.xpm");
 
     if (rolloverTitleButtons) {
-           closePixmap[2] = paths.loadPixmap(0, "closeO.xpm");
-           depthPixmap[2] = paths.loadPixmap(0, "depthO.xpm");
-        maximizePixmap[2] = paths.loadPixmap(0, "maximizeO.xpm");
-        minimizePixmap[2] = paths.loadPixmap(0, "minimizeO.xpm");
-         restorePixmap[2] = paths.loadPixmap(0, "restoreO.xpm");
-            hidePixmap[2] = paths.loadPixmap(0, "hideO.xpm");
-          rollupPixmap[2] = paths.loadPixmap(0, "rollupO.xpm");
-        rolldownPixmap[2] = paths.loadPixmap(0, "rolldownO.xpm");
+           closePixmap[2] = paths->loadPixmap(0, "closeO.xpm");
+           depthPixmap[2] = paths->loadPixmap(0, "depthO.xpm");
+        maximizePixmap[2] = paths->loadPixmap(0, "maximizeO.xpm");
+        minimizePixmap[2] = paths->loadPixmap(0, "minimizeO.xpm");
+         restorePixmap[2] = paths->loadPixmap(0, "restoreO.xpm");
+            hidePixmap[2] = paths->loadPixmap(0, "hideO.xpm");
+          rollupPixmap[2] = paths->loadPixmap(0, "rollupO.xpm");
+        rolldownPixmap[2] = paths->loadPixmap(0, "rolldownO.xpm");
     }
-        frameTL[0][0] = paths.loadPixmap(0, "frameITL.xpm");
-        frameTR[0][0] = paths.loadPixmap(0, "frameITR.xpm");
-        frameBL[0][0] = paths.loadPixmap(0, "frameIBL.xpm");
-        frameBR[0][0] = paths.loadPixmap(0, "frameIBR.xpm");
-        frameTL[0][1] = paths.loadPixmap(0, "frameATL.xpm");
-        frameTR[0][1] = paths.loadPixmap(0, "frameATR.xpm");
-        frameBL[0][1] = paths.loadPixmap(0, "frameABL.xpm");
-        frameBR[0][1] = paths.loadPixmap(0, "frameABR.xpm");
+        frameTL[0][0] = paths->loadPixmap(0, "frameITL.xpm");
+        frameTR[0][0] = paths->loadPixmap(0, "frameITR.xpm");
+        frameBL[0][0] = paths->loadPixmap(0, "frameIBL.xpm");
+        frameBR[0][0] = paths->loadPixmap(0, "frameIBR.xpm");
+        frameTL[0][1] = paths->loadPixmap(0, "frameATL.xpm");
+        frameTR[0][1] = paths->loadPixmap(0, "frameATR.xpm");
+        frameBL[0][1] = paths->loadPixmap(0, "frameABL.xpm");
+        frameBR[0][1] = paths->loadPixmap(0, "frameABR.xpm");
 
-        frameTL[1][0] = paths.loadPixmap(0, "dframeITL.xpm");
-        frameTR[1][0] = paths.loadPixmap(0, "dframeITR.xpm");
-        frameBL[1][0] = paths.loadPixmap(0, "dframeIBL.xpm");
-        frameBR[1][0] = paths.loadPixmap(0, "dframeIBR.xpm");
-        frameTL[1][1] = paths.loadPixmap(0, "dframeATL.xpm");
-        frameTR[1][1] = paths.loadPixmap(0, "dframeATR.xpm");
-        frameBL[1][1] = paths.loadPixmap(0, "dframeABL.xpm");
-        frameBR[1][1] = paths.loadPixmap(0, "dframeABR.xpm");
+        frameTL[1][0] = paths->loadPixmap(0, "dframeITL.xpm");
+        frameTR[1][0] = paths->loadPixmap(0, "dframeITR.xpm");
+        frameBL[1][0] = paths->loadPixmap(0, "dframeIBL.xpm");
+        frameBR[1][0] = paths->loadPixmap(0, "dframeIBR.xpm");
+        frameTL[1][1] = paths->loadPixmap(0, "dframeATL.xpm");
+        frameTR[1][1] = paths->loadPixmap(0, "dframeATR.xpm");
+        frameBL[1][1] = paths->loadPixmap(0, "dframeABL.xpm");
+        frameBR[1][1] = paths->loadPixmap(0, "dframeABR.xpm");
 
         if (TEST_GRADIENT(rgbFrameT[0][0] == null))
-            frameT[0][0] = paths.loadPixmap(0, "frameIT.xpm");
+            frameT[0][0] = paths->loadPixmap(0, "frameIT.xpm");
         if (TEST_GRADIENT(rgbFrameL[0][0] == null))
-            frameL[0][0] = paths.loadPixmap(0, "frameIL.xpm");
+            frameL[0][0] = paths->loadPixmap(0, "frameIL.xpm");
         if (TEST_GRADIENT( rgbFrameR[0][0] == null))
-            frameR[0][0] = paths.loadPixmap(0, "frameIR.xpm");
+            frameR[0][0] = paths->loadPixmap(0, "frameIR.xpm");
         if (TEST_GRADIENT(rgbFrameB[0][0] == null))
-            frameB[0][0] = paths.loadPixmap(0, "frameIB.xpm");
+            frameB[0][0] = paths->loadPixmap(0, "frameIB.xpm");
         if (TEST_GRADIENT(rgbFrameT[0][1] == null))
-            frameT[0][1] = paths.loadPixmap(0, "frameAT.xpm");
+            frameT[0][1] = paths->loadPixmap(0, "frameAT.xpm");
         if (TEST_GRADIENT(rgbFrameL[0][1] == null))
-            frameL[0][1] = paths.loadPixmap(0, "frameAL.xpm");
+            frameL[0][1] = paths->loadPixmap(0, "frameAL.xpm");
         if (TEST_GRADIENT(rgbFrameR[0][1] == null))
-            frameR[0][1] = paths.loadPixmap(0, "frameAR.xpm");
+            frameR[0][1] = paths->loadPixmap(0, "frameAR.xpm");
         if (TEST_GRADIENT(rgbFrameB[0][1] == null))
-            frameB[0][1] = paths.loadPixmap(0, "frameAB.xpm");
+            frameB[0][1] = paths->loadPixmap(0, "frameAB.xpm");
 
         if (TEST_GRADIENT(rgbFrameT[1][0] == null))
-            frameT[1][0] = paths.loadPixmap(0, "dframeIT.xpm");
+            frameT[1][0] = paths->loadPixmap(0, "dframeIT.xpm");
         if (TEST_GRADIENT(rgbFrameL[1][0] == null))
-            frameL[1][0] = paths.loadPixmap(0, "dframeIL.xpm");
+            frameL[1][0] = paths->loadPixmap(0, "dframeIL.xpm");
         if (TEST_GRADIENT(rgbFrameR[1][0] == null))
-            frameR[1][0] = paths.loadPixmap(0, "dframeIR.xpm");
+            frameR[1][0] = paths->loadPixmap(0, "dframeIR.xpm");
         if (TEST_GRADIENT(rgbFrameB[1][0] == null))
-            frameB[1][0] = paths.loadPixmap(0, "dframeIB.xpm");
+            frameB[1][0] = paths->loadPixmap(0, "dframeIB.xpm");
         if (TEST_GRADIENT(rgbFrameT[1][1] == null))
-            frameT[1][1] = paths.loadPixmap(0, "dframeAT.xpm");
+            frameT[1][1] = paths->loadPixmap(0, "dframeAT.xpm");
         if (TEST_GRADIENT(rgbFrameL[1][1] == null))
-            frameL[1][1] = paths.loadPixmap(0, "dframeAL.xpm");
+            frameL[1][1] = paths->loadPixmap(0, "dframeAL.xpm");
         if (TEST_GRADIENT(rgbFrameR[1][1] == null))
-            frameR[1][1] = paths.loadPixmap(0, "dframeAR.xpm");
+            frameR[1][1] = paths->loadPixmap(0, "dframeAR.xpm");
         if (TEST_GRADIENT(rgbFrameB[1][1] == null))
-            frameB[1][1] = paths.loadPixmap(0, "dframeAB.xpm");
+            frameB[1][1] = paths->loadPixmap(0, "dframeAB.xpm");
 
-        titleJ[0] = paths.loadPixmap(0, "titleIJ.xpm");
-        titleL[0] = paths.loadPixmap(0, "titleIL.xpm");
-        titleP[0] = paths.loadPixmap(0, "titleIP.xpm");
-        titleM[0] = paths.loadPixmap(0, "titleIM.xpm");
-        titleR[0] = paths.loadPixmap(0, "titleIR.xpm");
-        titleQ[0] = paths.loadPixmap(0, "titleIQ.xpm");
-        titleJ[1] = paths.loadPixmap(0, "titleAJ.xpm");
-        titleL[1] = paths.loadPixmap(0, "titleAL.xpm");
-        titleP[1] = paths.loadPixmap(0, "titleAP.xpm");
-        titleM[1] = paths.loadPixmap(0, "titleAM.xpm");
-        titleR[1] = paths.loadPixmap(0, "titleAR.xpm");
-        titleQ[1] = paths.loadPixmap(0, "titleAQ.xpm");
+        titleJ[0] = paths->loadPixmap(0, "titleIJ.xpm");
+        titleL[0] = paths->loadPixmap(0, "titleIL.xpm");
+        titleP[0] = paths->loadPixmap(0, "titleIP.xpm");
+        titleM[0] = paths->loadPixmap(0, "titleIM.xpm");
+        titleR[0] = paths->loadPixmap(0, "titleIR.xpm");
+        titleQ[0] = paths->loadPixmap(0, "titleIQ.xpm");
+        titleJ[1] = paths->loadPixmap(0, "titleAJ.xpm");
+        titleL[1] = paths->loadPixmap(0, "titleAL.xpm");
+        titleP[1] = paths->loadPixmap(0, "titleAP.xpm");
+        titleM[1] = paths->loadPixmap(0, "titleAM.xpm");
+        titleR[1] = paths->loadPixmap(0, "titleAR.xpm");
+        titleQ[1] = paths->loadPixmap(0, "titleAQ.xpm");
 
 //      if (TEST_GRADIENT(NULL == rgbTitleS[0]))
-            titleS[0] = paths.loadPixmap(0, "titleIS.xpm");
+            titleS[0] = paths->loadPixmap(0, "titleIS.xpm");
 //      if (TEST_GRADIENT(NULL == rgbTitleT[0]))
-            titleT[0] = paths.loadPixmap(0, "titleIT.xpm");
+            titleT[0] = paths->loadPixmap(0, "titleIT.xpm");
 //      if (TEST_GRADIENT(NULL == rgbTitleB[0]))
-            titleB[0] = paths.loadPixmap(0, "titleIB.xpm");
+            titleB[0] = paths->loadPixmap(0, "titleIB.xpm");
 //      if (TEST_GRADIENT(NULL == rgbTitleS[1]))
-            titleS[1] = paths.loadPixmap(0, "titleAS.xpm");
+            titleS[1] = paths->loadPixmap(0, "titleAS.xpm");
 //      if (TEST_GRADIENT(NULL == rgbTitleT[1]))
-            titleT[1] = paths.loadPixmap(0, "titleAT.xpm");
+            titleT[1] = paths->loadPixmap(0, "titleAT.xpm");
 //      if (TEST_GRADIENT(NULL == rgbTitleB[1]))
-            titleB[1] = paths.loadPixmap(0, "titleAB.xpm");
+            titleB[1] = paths->loadPixmap(0, "titleAB.xpm");
 #ifdef CONFIG_SHAPED_DECORATION
         bool const copyMask(true);
 #else
@@ -617,67 +630,75 @@ static void initPixmaps() {
             titleB[a]->replicate(true, copyMask);
         }
 
-        menuButton[0] = paths.loadPixmap(0, "menuButtonI.xpm");
-        menuButton[1] = paths.loadPixmap(0, "menuButtonA.xpm");
+        menuButton[0] = paths->loadPixmap(0, "menuButtonI.xpm");
+        menuButton[1] = paths->loadPixmap(0, "menuButtonA.xpm");
     if (rolloverTitleButtons) {
-        menuButton[2] = paths.loadPixmap(0, "menuButtonO.xpm");
+        menuButton[2] = paths->loadPixmap(0, "menuButtonO.xpm");
     }
     }
 #endif
-    if (depthPixmap[0]==null)       depthPixmap[0] = paths.loadPixmap(0, "depth.xpm");
-    if (closePixmap[0]==null)       closePixmap[0] = paths.loadPixmap(0, "close.xpm");
-    if (maximizePixmap[0]==null)    maximizePixmap[0] = paths.loadPixmap(0, "maximize.xpm");
-    if (minimizePixmap[0]==null)    minimizePixmap[0] = paths.loadPixmap(0, "minimize.xpm");
-    if (restorePixmap[0]==null)     restorePixmap[0] = paths.loadPixmap(0, "restore.xpm");
-    if (hidePixmap[0]==null)        hidePixmap[0] = paths.loadPixmap(0, "hide.xpm");
-    if (rollupPixmap[0]==null)      rollupPixmap[0] = paths.loadPixmap(0, "rollup.xpm");
-    if (rolldownPixmap[0]==null)    rolldownPixmap[0] = paths.loadPixmap(0, "rolldown.xpm");
+    {
+      if (depthPixmap[0]==null)            depthPixmap[0] = paths->loadPixmap(0, "depth.xpm");
+      if (closePixmap[0]==null)            closePixmap[0] = paths->loadPixmap(0, "close.xpm");
+      if (maximizePixmap[0]==null)      maximizePixmap[0] = paths->loadPixmap(0, "maximize.xpm");
+      if (minimizePixmap[0]==null)      minimizePixmap[0] = paths->loadPixmap(0, "minimize.xpm");
+      if (restorePixmap[0]==null)        restorePixmap[0] = paths->loadPixmap(0, "restore.xpm");
+      if (hidePixmap[0]==null)              hidePixmap[0] = paths->loadPixmap(0, "hide.xpm");
+      if (rollupPixmap[0]==null)          rollupPixmap[0] = paths->loadPixmap(0, "rollup.xpm");
+      if (rolldownPixmap[0]==null)      rolldownPixmap[0] = paths->loadPixmap(0, "rolldown.xpm");
+    }
 
     if (TEST_GRADIENT(logoutPixbuf == null))
-        logoutPixmap = paths.loadPixmap(0, "logoutbg.xpm");
+        logoutPixmap = paths->loadPixmap(0, "logoutbg.xpm");
     if (TEST_GRADIENT(switchbackPixbuf == null))
-        switchbackPixmap = paths.loadPixmap(0, "switchbg.xpm");
+        switchbackPixmap = paths->loadPixmap(0, "switchbg.xpm");
     if (TEST_GRADIENT(menubackPixbuf == null))
-        menubackPixmap = paths.loadPixmap(0, "menubg.xpm");
+        menubackPixmap = paths->loadPixmap(0, "menubg.xpm");
     if (TEST_GRADIENT(menuselPixbuf == null))
-        menuselPixmap = paths.loadPixmap(0, "menusel.xpm");
+        menuselPixmap = paths->loadPixmap(0, "menusel.xpm");
     if (TEST_GRADIENT(menusepPixbuf == null))
-        menusepPixmap = paths.loadPixmap(0, "menusep.xpm");
+        menusepPixmap = paths->loadPixmap(0, "menusep.xpm");
 
 #ifndef LITE
     if (TEST_GRADIENT(listbackPixbuf == null) &&
-        (listbackPixmap = paths.loadPixmap(0, "listbg.xpm")) == null)
+        (listbackPixmap = paths->loadPixmap(0, "listbg.xpm")) == null)
         listbackPixmap = menubackPixmap;
 #endif
     if (TEST_GRADIENT(dialogbackPixbuf == null) &&
-        (dialogbackPixmap = paths.loadPixmap(0, "dialogbg.xpm")) == null)
+        (dialogbackPixmap = paths->loadPixmap(0, "dialogbg.xpm")) == null)
         dialogbackPixmap = menubackPixmap;
     if (TEST_GRADIENT(buttonIPixbuf == null) &&
-        (buttonIPixmap = paths.loadPixmap(0, "buttonI.xpm")) == null)
-        buttonIPixmap = paths.loadPixmap("taskbar/", "taskbuttonbg.xpm");
+        (buttonIPixmap = paths->loadPixmap(0, "buttonI.xpm")) == null)
+        buttonIPixmap = paths->loadPixmap("taskbar/", "taskbuttonbg.xpm");
     if (TEST_GRADIENT(buttonAPixbuf == null) &&
-        (buttonAPixmap = paths.loadPixmap(0, "buttonA.xpm")) == null)
-        buttonAPixmap = paths.loadPixmap("taskbar/", "taskbuttonactive.xpm");
+        (buttonAPixmap = paths->loadPixmap(0, "buttonA.xpm")) == null)
+        buttonAPixmap = paths->loadPixmap("taskbar/", "taskbuttonactive.xpm");
 
 #ifdef CONFIG_TASKBAR
     if (TEST_GRADIENT(toolbuttonPixbuf == null) &&
         (toolbuttonPixmap =
-         paths.loadPixmap("taskbar/", "toolbuttonbg.xpm")) == null)
+         paths->loadPixmap("taskbar/", "toolbuttonbg.xpm")) == null)
+    {
         IF_CONFIG_GRADIENTS (buttonIPixbuf != null,
                              toolbuttonPixbuf = buttonIPixbuf)
-                        else toolbuttonPixmap = buttonIPixmap;
+        else toolbuttonPixmap = buttonIPixmap;
+    }
     if (TEST_GRADIENT(workspacebuttonPixbuf == null) &&
         (workspacebuttonPixmap =
-         paths.loadPixmap("taskbar/", "workspacebuttonbg.xpm")) == null)
+         paths->loadPixmap("taskbar/", "workspacebuttonbg.xpm")) == null)
+    {
         IF_CONFIG_GRADIENTS (buttonIPixbuf != null,
                              workspacebuttonPixbuf = buttonIPixbuf)
-                        else workspacebuttonPixmap = buttonIPixmap;
+        else workspacebuttonPixmap = buttonIPixmap;
+    }
     if (TEST_GRADIENT(workspacebuttonactivePixbuf == null) &&
         (workspacebuttonactivePixmap =
-         paths.loadPixmap("taskbar/", "workspacebuttonactive.xpm")) == null)
+         paths->loadPixmap("taskbar/", "workspacebuttonactive.xpm")) == null)
+    {
         IF_CONFIG_GRADIENTS (buttonAPixbuf != null,
                              workspacebuttonactivePixbuf = buttonAPixbuf)
-                        else workspacebuttonactivePixmap = buttonAPixmap;
+        else workspacebuttonactivePixmap = buttonAPixmap;
+    }
 #endif
 
     if (logoutPixmap != null) {
@@ -729,8 +750,8 @@ static void initMenus() {
 
         logoutMenu->setShared(true); /// !!! get rid of this (refcount objects)
         if (showLogoutSubMenu) {
-            logoutMenu->addItem(_("_Logout"), -2, "", actionLogout)->setChecked(true);
-            logoutMenu->addItem(_("_Cancel logout"), -2, "", actionCancelLogout)->setEnabled(false);
+            logoutMenu->addItem(_("_Logout"), -2, null, actionLogout)->setChecked(true);
+            logoutMenu->addItem(_("_Cancel logout"), -2, null, actionCancelLogout)->setEnabled(false);
             logoutMenu->addSeparator();
 
 #ifndef NO_CONFIGURE_MENUS
@@ -740,21 +761,20 @@ static void initMenus() {
 #define canLock() true
 #define canShutdown(x) true
 #endif
+            int const oldItemCount = logoutMenu->itemCount();
             if (canLock())
-                logoutMenu->addItem(_("Lock _Workstation"), -2, "", actionLock);
+                logoutMenu->addItem(_("Lock _Workstation"), -2, null, actionLock);
             if (canShutdown(true))
-                logoutMenu->addItem(_("Re_boot"), -2, "", actionReboot);
+                logoutMenu->addItem(_("Re_boot"), -2, null, actionReboot);
             if (canShutdown(false))
-                logoutMenu->addItem(_("Shut_down"), -2, "", actionShutdown);
-            logoutMenu->addSeparator();
+                logoutMenu->addItem(_("Shut_down"), -2, null, actionShutdown);
+            if (logoutMenu->itemCount() != oldItemCount)
+                logoutMenu->addSeparator();
 
-            DProgram *restartIcewm =
-                DProgram::newProgram(_("Restart _Icewm"), 0, true, 0, 0, noargs);
-            if (restartIcewm)
-                logoutMenu->add(new DObjectMenuItem(restartIcewm));
+            logoutMenu->addItem(_("Restart _Icewm"), -2, null, actionRestart);
 
             DProgram *restartXTerm =
-                DProgram::newProgram(_("Restart _Xterm"), 0, true, 0, "x-terminal-emulator", noargs);
+                DProgram::newProgram(_("Restart _Xterm"), null, true, 0, "xterm", noargs);
             if (restartXTerm)
                 logoutMenu->add(new DObjectMenuItem(restartXTerm));
 #endif
@@ -769,13 +789,13 @@ static void initMenus() {
     assert(layerMenu != 0);
     layerMenu->setShared(true);
 
-    layerMenu->addItem(_("_Menu"),       -2, 0, layerActionSet[WinLayerMenu]);
-    layerMenu->addItem(_("_Above Dock"), -2, 0, layerActionSet[WinLayerAboveDock]);
-    layerMenu->addItem(_("_Dock"),       -2, 0, layerActionSet[WinLayerDock]);
-    layerMenu->addItem(_("_OnTop"),      -2, 0, layerActionSet[WinLayerOnTop]);
-    layerMenu->addItem(_("_Normal"),     -2, 0, layerActionSet[WinLayerNormal]);
-    layerMenu->addItem(_("_Below"),      -2, 0, layerActionSet[WinLayerBelow]);
-    layerMenu->addItem(_("D_esktop"),    -2, 0, layerActionSet[WinLayerDesktop]);
+    layerMenu->addItem(_("_Menu"),       -2, null, layerActionSet[WinLayerMenu]);
+    layerMenu->addItem(_("_Above Dock"), -2, null, layerActionSet[WinLayerAboveDock]);
+    layerMenu->addItem(_("_Dock"),       -2, null, layerActionSet[WinLayerDock]);
+    layerMenu->addItem(_("_OnTop"),      -2, null, layerActionSet[WinLayerOnTop]);
+    layerMenu->addItem(_("_Normal"),     -2, null, layerActionSet[WinLayerNormal]);
+    layerMenu->addItem(_("_Below"),      -2, null, layerActionSet[WinLayerBelow]);
+    layerMenu->addItem(_("D_esktop"),    -2, null, layerActionSet[WinLayerDesktop]);
 
     moveMenu = new YMenu();
     assert(moveMenu != 0);
@@ -783,7 +803,7 @@ static void initMenus() {
     for (int w = 0; w < workspaceCount; w++) {
         char s[128];
         sprintf(s, "%lu. %s", (unsigned long)(w + 1), workspaceNames[w]);
-        moveMenu->addItem(s, 0, 0, workspaceActionMoveTo[w]);
+        moveMenu->addItem(s, 0, null, workspaceActionMoveTo[w]);
     }
 
     if (strchr(winMenuItems, 'r'))
@@ -826,12 +846,12 @@ static void initMenus() {
     /// this should probably go away, cause fullscreen will do mostly the same thing
 #if DO_NOT_COVER_OLD
     if (!limitByDockLayer)
-        windowMenu->addItem(_("Limit _Workarea"), -2, 0, actionDoNotCover);
+        windowMenu->addItem(_("Limit _Workarea"), -2, null, actionDoNotCover);
 #endif
 
 #ifdef CONFIG_TRAY
     if (strchr(winMenuItems, 'i') && taskBarShowTray)
-        windowMenu->addItem(_("Tray _icon"), -2, 0, actionToggleTray);
+        windowMenu->addItem(_("Tray _icon"), -2, null, actionToggleTray);
 #endif
 
     if (strchr(winMenuItems, 'c') || strchr(winMenuItems, 'k'))
@@ -919,10 +939,10 @@ int handler(Display *display, XErrorEvent *xev) {
         if (XGetErrorText(display,
                           xev->error_code,
                           message, sizeof(message)) !=
-                          Success);
+                          Success)
             *message = '\0';
 
-        warn(_("X error %s(0x%lX): %s"), req, xev->resourceid, message);
+        warn("X error %s(0x%lX): %s", req, xev->resourceid, message);
     }
     return 0;
 }
@@ -932,9 +952,10 @@ void dumpZorder(const char *oper, YFrameWindow *w, YFrameWindow *a) {
     YFrameWindow *p = manager->top(w->getActiveLayer());
     msg("---- %s ", oper);
     while (p) {
-        if (p && p->client())
-            msg(" %c %c 0x%lX: %s", (p == w) ? '*' : ' ',  (p == a) ? '#' : ' ', p->client()->handle(), p->client()->windowTitle());
-        else
+        if (p && p->client()) {
+            cstring cs(p->client()->windowTitle());
+            msg(" %c %c 0x%lX: %s", (p == w) ? '*' : ' ',  (p == a) ? '#' : ' ', p->client()->handle(), cs.c_str());
+        } else
             msg("?? 0x%lX: %s", p->handle());
         PRECONDITION(p->next() != p);
         PRECONDITION(p->prev() != p);
@@ -1031,6 +1052,8 @@ void YWMApp::actionPerformed(YAction *action, unsigned int /*modifiers*/) {
         manager->doWMAction(ICEWM_ACTION_SHUTDOWN);
     } else if (action == actionReboot) {
         manager->doWMAction(ICEWM_ACTION_REBOOT);
+    } else if (action == actionRestart) {
+        restartClient(0, 0);
     } else if (action == actionRun) {
         runCommand(runDlgCommand);
     } else if (action == actionExit) {
@@ -1140,9 +1163,7 @@ YWMApp::YWMApp(int *argc, char ***argv, const char *displayName):
     if (themeName != 0) {
         MSG(("themeName=%s", themeName));
 
-        char *theme = strJoin("themes/", themeName, NULL);
-        loadThemeConfiguration(theme);
-        delete [] theme;
+        loadThemeConfiguration(themeName);
     }
     {
         cfoption focus_prefs[] = {
@@ -1150,7 +1171,7 @@ YWMApp::YWMApp(int *argc, char ***argv, const char *displayName):
             OK0()
         };
 
-        app->loadConfig(focus_prefs, "focus_mode");
+        YConfig::findLoadConfigFile(focus_prefs, "focus_mode");
     }
     loadConfiguration("prefoverride");
     switch (focusMode) {
@@ -1199,11 +1220,11 @@ YWMApp::YWMApp(int *argc, char ***argv, const char *displayName):
         addWorkspace(0, " 0 ", false);
 
 #ifndef NO_WINDOW_OPTIONS
-    if (winOptFile == 0)
+    if (winOptFile == null)
         winOptFile = app->findConfigFile("winoptions");
 #endif
 
-    if (keysFile == 0)
+    if (keysFile == null)
         keysFile = app->findConfigFile("keys");
 
     catchSignal(SIGINT);
@@ -1215,13 +1236,13 @@ YWMApp::YWMApp(int *argc, char ***argv, const char *displayName):
 #ifndef NO_WINDOW_OPTIONS
     defOptions = new WindowOptions();
     hintOptions = new WindowOptions();
-    if (winOptFile)
+    if (winOptFile != null)
         loadWinOptions(winOptFile);
-    delete[] winOptFile; winOptFile = 0;
+    winOptFile = null;
 #endif
 
 #ifndef NO_CONFIGURE_MENUS
-    if (keysFile)
+    if (keysFile != null)
         loadMenus(keysFile, 0);
 #endif
 
@@ -1438,13 +1459,14 @@ void YWMApp::handleSignal(int sig) {
     }
 }
 
-void YWMApp::handleIdle() {
+bool YWMApp::handleIdle() {
 #ifdef CONFIG_TASKBAR
 /// TODO #warning "make this generic"
     if (taskBar) {
         taskBar->relayoutNow();
     }
 #endif
+    return YSMApplication::handleIdle();
 }
 
 #ifdef CONFIG_GUIEVENTS
@@ -1475,11 +1497,11 @@ void YWMApp::afterWindowEvent(XEvent &xev) {
     static XEvent lastKeyEvent = { 0 };
 
     if (xev.type == KeyRelease && lastKeyEvent.type == KeyPress) {
-        KeySym k1 = XKeycodeToKeysym(xapp->display(), xev.xkey.keycode, 0);
+        KeySym k1 = XKeycodeToKeysym(xapp->display(), (KeyCode)xev.xkey.keycode, 0);
         unsigned int m1 = KEY_MODMASK(lastKeyEvent.xkey.state);
-        KeySym k2 = XKeycodeToKeysym(xapp->display(), lastKeyEvent.xkey.keycode, 0);
+        KeySym k2 = XKeycodeToKeysym(xapp->display(), (KeyCode)lastKeyEvent.xkey.keycode, 0);
 
-        if (m1 == 0 && xapp->WinMask && win95keys)
+        if (m1 == 0 && xapp->WinMask && win95keys) {
             if (k1 == xapp->Win_L && k2 == xapp->Win_L) {
                 manager->popupStartMenu(desktop);
             }
@@ -1489,6 +1511,7 @@ void YWMApp::afterWindowEvent(XEvent &xev) {
                     windowList->showFocused(-1, -1);
             }
 #endif
+        }
     }
 
     if (xev.type == KeyPress ||
@@ -1595,8 +1618,8 @@ int main(int argc, char **argv) {
             OK0()
         };
 
-        app->loadConfig(theme_prefs, "preferences");
-        app->loadConfig(theme_prefs, "theme");
+        YConfig::findLoadConfigFile(theme_prefs, "preferences");
+        YConfig::findLoadConfigFile(theme_prefs, "theme");
     }
     if (overrideTheme)
         themeName = newstr(overrideTheme);
