@@ -106,7 +106,7 @@ void YFrameButton::actionPerformed(YAction * /*action*/, unsigned int modifiers)
         getFrame()->actionPerformed(fAction, modifiers);
 }
 
-ref<YPixmap> YFrameButton::getImage(int pn) const {
+ref<YPixmap> YFrameButton::getPixmap(int pn) const {
     if (fAction == actionMaximize)
         return maximizePixmap[pn];
     else if (fAction == actionMinimize)
@@ -148,18 +148,21 @@ void YFrameButton::paint(Graphics &g, const YRect &/*r*/) {
         }
     }
 
-
-
+    int iconSize =
 #ifdef LITE
-    ref<YIconImage> icon;
+        0;
 #else
-    ref<YIconImage> icon =
-        (fAction == 0 && getFrame()->clientIcon()) ?
-        getFrame()->clientIcon()->small() : null;
+    YIcon::smallSize();
+#endif
+#ifdef LITE
+    ref<YIcon> icon;
+#else
+    ref<YIcon> icon =
+        (fAction == 0) ? getFrame()->clientIcon() : null;
 #endif
 
-    ref<YPixmap> pixmap = getImage(pn); 
-    if (pixmap==null) pixmap=getImage(0); 
+    ref<YPixmap> pixmap = getPixmap(pn);
+    if (pixmap == null) pixmap = getPixmap(0);
 
     switch (wmLook) {
 #ifdef CONFIG_LOOK_WARP4
@@ -173,8 +176,10 @@ void YFrameButton::paint(Graphics &g, const YRect &/*r*/) {
             g.fillRect(1, 1, width() - 2, height() - 2);
 
             if (icon != null && showFrameIcon)
-                g.drawImage(icon, (width() - icon->width()) / 2,
-                            (height() - icon->height()) / 2);
+                icon->draw(g,
+                           (width() - iconSize) / 2,
+                           (height() - iconSize) / 2,
+                           iconSize);
         } else {
             g.fillRect(0, 0, width(), height());
 
@@ -222,8 +227,10 @@ void YFrameButton::paint(Graphics &g, const YRect &/*r*/) {
             g.fillRect(xPos, yPos, w, h);
 
             if (icon != null && showFrameIcon)
-                g.drawImage(icon, xPos + (w - icon->width()) / 2,
-                            yPos + (h - icon->height()) / 2);
+                icon->draw(g,
+                           xPos + (w - iconSize) / 2,
+                           yPos + (h - iconSize) / 2,
+                           iconSize);
         } else {
             if (pixmap != null)
                 g.drawCenteredPixmap(xPos, yPos, w, h, pixmap);
@@ -245,8 +252,10 @@ CASE_LOOK_WIN95:
             g.fillRect(0, 0, width(), height());
 
             if (icon != null && showFrameIcon)
-                g.drawImage(icon, (width() - icon->width()) / 2,
-                            (height() - icon->height()) / 2);
+                icon->draw(g,
+                           (width() - iconSize) / 2,
+                           (height() - iconSize) / 2,
+                           iconSize);
         } else {
             g.drawBorderW(0, 0, width() - 1, height() - 1, !armed);
 
@@ -265,7 +274,7 @@ CASE_LOOK_WIN95:
     case lookFlat:
     case lookGtk:
         if (pixmap != null) {
-            if ( getImage(1) != null ) {
+            if ( getPixmap(1) != null ) {
             int const h(pixmap->height() / 2);
             g.copyPixmap(pixmap, 0, armed ? h : 0, pixmap->width(), h, 0, 0);
             } else { //If we have only an image we change the over or armed color and paint it
@@ -283,8 +292,10 @@ CASE_LOOK_WIN95:
             g.fillRect(0, 0, width(), height());
 
         if (fAction == 0 && icon != null && showFrameIcon)
-            g.drawImage(icon, ((int)width() - (int)icon->width()) / 2,
-                        ((int)height() - (int)icon->height()) / 2);
+            icon->draw(g,
+                       ((int)width() - (int)iconSize) / 2,
+                       ((int)height() - (int)iconSize) / 2,
+                       iconSize);
 
         break;
 #endif
