@@ -19,10 +19,10 @@ public:
 #endif
     virtual YFrameWindow *owner() const = 0;
 #ifndef LITE
-    virtual YIcon *getIcon() const = 0;
+    virtual ref<YIcon> getIcon() const = 0;
 #endif
-    virtual const char *getTitle() const = 0;
-    virtual const char *getIconTitle() const = 0;
+    virtual ustring getTitle() const = 0;
+    virtual ustring getIconTitle() const = 0;
     virtual void activateWindow(bool raise) = 0;
     virtual bool isHidden() const = 0;
     virtual bool isMinimized() const = 0;
@@ -94,6 +94,11 @@ public:
 
     void getSizeHints();
     XSizeHints *sizeHints() const { return fSizeHints; }
+    
+    // for going fullscreen and back
+    XSizeHints savedSizeHints;
+    void saveSizeHints();
+    void restoreSizeHints();
 
     unsigned long protocols() const { return fProtocols; }
     void getProtocols(bool force);
@@ -112,8 +117,8 @@ public:
     void setWindowTitle(const XTextProperty & title);
     void setIconTitle(const XTextProperty & title);
 #endif
-    const char *windowTitle() { return fWindowTitle; }
-    const char *iconTitle() { return fIconTitle; }
+    ustring windowTitle() { return fWindowTitle; }
+    ustring iconTitle() { return fIconTitle; }
 
     bool getWinIcons(Atom *type, int *count, long **elem);
 
@@ -136,6 +141,7 @@ public:
     long winHints() const { return fWinHints; }
 
 #ifdef WMSPEC_HINTS
+    bool getNetWMIcon(int *count, long **elem);
     bool getNetWMStateHint(long *mask, long *state);
     bool getNetWMDesktopHint(long *workspace);
     bool getNetWMStrut(int *left, int *right, int *top, int *bottom);
@@ -164,12 +170,12 @@ public:
     void getWMWindowRole();
 
     Window clientLeader() const { return fClientLeader; }
-    const char *windowRole() const { return fWMWindowRole ? fWMWindowRole : fWindowRole; }
+    ustring windowRole() const { return fWMWindowRole != null ? fWMWindowRole : fWindowRole; }
 
-    char *getClientId(Window leader);
+    ustring getClientId(Window leader);
     void getPropertiesList();
 
-    void configure(const YRect &/*r*/, const bool /*resized*/);
+    void configure(const YRect &/*r*/);
 
     bool isKdeTrayWindow() { return prop.kde_net_wm_system_tray_window_for; }
 
@@ -188,12 +194,12 @@ private:
     bool fShaped;
     long fWinHints;
 
-    char *fWindowTitle;
-    char *fIconTitle;
+    ustring fWindowTitle;
+    ustring fIconTitle;
 
     Window fClientLeader;
-    char *fWMWindowRole;
-    char *fWindowRole;
+    ustring fWMWindowRole;
+    ustring fWindowRole;
 
     MwmHints *fMwmHints;
 
@@ -216,6 +222,7 @@ private:
         bool kwm_win_icon : 1;
         bool kde_net_wm_system_tray_window_for : 1;
 #ifdef WMSPEC_HINTS
+        bool net_wm_icon : 1;
         bool net_wm_strut : 1;
         bool net_wm_desktop : 1; // no property notify
         bool net_wm_state : 1; // no property notify
