@@ -4,7 +4,7 @@
 extern bool configurationNeeded;
 
 void loadConfiguration(const char *fileName);
-void loadThemeConfiguration(const char *fileName);
+void loadThemeConfiguration(const char *themeName);
 void addWorkspace(const char *name, const char *value, bool append);
 void setLook(const char *name, const char *value, bool append);
 void freeConfiguration();
