@@ -24,6 +24,14 @@ class TrayPane;
 class WorkspacesPane;
 class YXTray;
 
+class IAppletContainer {
+public:
+    virtual void relayout() = 0;
+    virtual void contextMenu(int x_root, int y_root) = 0;
+protected:
+    virtual ~IAppletContainer() {}
+};
+
 #ifdef CONFIG_TASKBAR
 class TaskBar;
 
@@ -50,7 +58,8 @@ class TaskBar:
     public YFrameClient,
     public YActionListener,
     public YPopDownListener,
-    public YXTrayNotifier
+    public YXTrayNotifier,
+    public IAppletContainer
 {
 public:
     TaskBar(YWindow *aParent);
@@ -74,29 +83,37 @@ public:
 
     void updateWMHints();
     void updateLocation();
-    void configure(const YRect &r, const bool resized);
+    void configure(const YRect &r);
 
 #ifdef CONFIG_APPLET_CLOCK
     YClock *clock() { return fClock; }
 #endif
 
+    bool windowTrayRequestDock(Window w);
+    void setWorkspaceActive(long workspace, int active);
+
+    void removeTasksApp(YFrameWindow *w);
+    class TaskBarApp *addTasksApp(YFrameWindow *w);
+    void relayoutTasks();
+
     WorkspacesPane *workspacesPane() const { return fWorkspaces; }
 
     void popupStartMenu();
     void popupWindowListMenu();
 
     void popOut();
+    void showAddressBar();
     void showBar(bool visible);
     void handleCollapseButton();
 
     AddressBar *addressBar() const { return fAddressBar; }
     TaskPane *taskPane() const { return fTasks; }
 #ifdef CONFIG_TRAY
-    TrayPane *trayPane() const { return fTray; }
+    TrayPane *windowTrayPane() const { return fWindowTray; }
 #endif
 
 #ifdef CONFIG_GRADIENTS
-    virtual ref<YPixbuf> getGradient() const { return fGradient; }
+    virtual ref<YImage> getGradient() const { return fGradient; }
 #endif    
 
     void contextMenu(int x_root, int y_root);
@@ -104,9 +121,13 @@ public:
     void relayout() { fNeedRelayout = true; }
     void relayoutNow();
 
-    void detachTray();
+    void detachDesktopTray();
     void trayChanged();
-    YXTray *netwmTray() { return fTray2; }
+    YXTray *netwmTray() { return fDesktopTray; }
+
+    void relayoutTray();
+    class TrayApp *addTrayApp(YFrameWindow *w);
+    void removeTrayApp(YFrameWindow *w);
 
     bool autoTimer(bool show);
     void updateFullscreen(bool fullscreen);
@@ -117,7 +138,7 @@ private:
 
     YButton *fCollapseButton;
 #ifdef CONFIG_TRAY
-    TrayPane *fTray;
+    TrayPane *fWindowTray;
 #endif
 #ifdef CONFIG_APPLET_CLOCK
     YClock *fClock;
@@ -145,7 +166,7 @@ private:
     YButton *fShowDesktop;
     AddressBar *fAddressBar;
     WorkspacesPane *fWorkspaces;
-    YXTray *fTray2;
+    YXTray *fDesktopTray;
 
     bool fIsHidden;
     bool fFullscreen;
@@ -162,7 +183,7 @@ private:
     friend class WindowListBox;
     
 #ifdef CONFIG_GRADIENTS
-    ref<YPixbuf> fGradient;
+    ref<YImage> fGradient;
 #endif
 
     bool fNeedRelayout;
@@ -187,14 +208,12 @@ extern ref<YPixmap> taskbuttonminimizedPixmap;
 #endif
 
 #ifdef CONFIG_GRADIENTS
-#if 1
 class YPixbuf;
 
-extern ref<YPixbuf> taskbackPixbuf;
-extern ref<YPixbuf> taskbuttonPixbuf;
-extern ref<YPixbuf> taskbuttonactivePixbuf;
-extern ref<YPixbuf> taskbuttonminimizedPixbuf;
-#endif
+extern ref<YImage> taskbackPixbuf;
+extern ref<YImage> taskbuttonPixbuf;
+extern ref<YImage> taskbuttonactivePixbuf;
+extern ref<YImage> taskbuttonminimizedPixbuf;
 #endif
 
 #endif
