@@ -32,7 +32,7 @@ extern ImlibData *hImlib;
 
 class YCursorPixmap {
 public:
-    YCursorPixmap(char const *path);
+    YCursorPixmap(upath path);
     ~YCursorPixmap();
 
     Pixmap pixmap() const { return fPixmap; }
@@ -56,6 +56,14 @@ public:
     unsigned int hotspotY() const { return fHotspotY; }
 #endif
 
+#ifdef CONFIG_GDK_PIXBUF_XLIB
+    bool isValid() { return false; }
+    unsigned int width() const { return 0; }
+    unsigned int height() const { return 0; }
+    unsigned int hotspotX() const { return fHotspotX; }
+    unsigned int hotspotY() const { return fHotspotY; }
+#endif
+
 private:
     Pixmap fPixmap, fMask;
     XColor fForeground, fBackground;
@@ -69,11 +77,16 @@ private:
     unsigned int fHotspotX, fHotspotY;
     ImlibImage *fImage;
 #endif
+
+#ifdef CONFIG_GDK_PIXBUF_XLIB
+    bool fValid;
+    unsigned int fHotspotX, fHotspotY;
+#endif
     operator bool();
 };
 
 #ifdef CONFIG_XPM // ================== use libXpm to load the cursor pixmap ===
-YCursorPixmap::YCursorPixmap(char const *path): fValid(false) {
+YCursorPixmap::YCursorPixmap(upath path): fValid(false) {
     fAttributes.colormap  = xapp->colormap();
     fAttributes.closeness = 65535;
     fAttributes.valuemask = XpmColormap|XpmCloseness|
@@ -82,14 +95,14 @@ YCursorPixmap::YCursorPixmap(char const *path): fValid(false) {
     fAttributes.y_hotspot = 0;
 
     int const rc(XpmReadFileToPixmap(xapp->display(), desktop->handle(),
-                                     (char *)REDIR_ROOT(path), // !!!
+                                     (char *)REDIR_ROOT(cstring(path.path()).c_str()), // !!!
                                      &fPixmap, &fMask, &fAttributes));
 
     if (rc != XpmSuccess)
         warn(_("Loading of pixmap \"%s\" failed: %s"),
                path, XpmGetErrorString(rc));
     else if (fAttributes.npixels != 2)
-        warn(_("Invalid cursor pixmap: \"%s\" contains too many unique colors"), 
+        warn("Invalid cursor pixmap: \"%s\" contains too many unique colors",
                path);
     else {
         fBackground.pixel = fAttributes.pixels[0];
@@ -104,12 +117,14 @@ YCursorPixmap::YCursorPixmap(char const *path): fValid(false) {
 #endif
 
 #ifdef CONFIG_IMLIB // ================= use Imlib to load the cursor pixmap ===
-YCursorPixmap::YCursorPixmap(char const *path):
-    fHotspotX(0), fHotspotY(0) {
-    fImage = Imlib_load_image(hImlib, (char *)REDIR_ROOT(path));
+YCursorPixmap::YCursorPixmap(upath path):
+    fHotspotX(0), fHotspotY(0)
+{
+    cstring cs(path.path());
+    fImage = Imlib_load_image(hImlib, (char *)REDIR_ROOT(cs.c_str()));
 
     if (fImage == NULL) {
-        warn(_("Loading of pixmap \"%s\" failed"), path);
+        warn(_("Loading of pixmap \"%s\" failed"), cs.c_str());
         return;
     }
     
@@ -143,7 +158,7 @@ YCursorPixmap::YCursorPixmap(char const *path):
                 default:
                     if (*pp != bg && *pp != fg) {
                         warn(_("Invalid cursor pixmap: \"%s\" contains too "
-                               "much unique colors"), path);
+                               "much unique colors"), cs.c_str());
 
                         Imlib_destroy_image(hImlib, fImage);
                         fImage = NULL;
@@ -162,9 +177,9 @@ YCursorPixmap::YCursorPixmap(char const *path):
     XAllocColor(xapp->display(), xapp->colormap(), &fBackground);
 
     // ----------------- find the hotspot by reading the xpm header manually ---
-    FILE *xpm = fopen((char *)REDIR_ROOT(path), "rb");
+    FILE *xpm = fopen((char *)REDIR_ROOT(cs.c_str()), "rb");
     if (xpm == NULL)
-        warn(_("BUG? Imlib was able to read \"%s\""), path);
+        warn(_("BUG? Imlib was able to read \"%s\""), cs.c_str());
 
     else {
         while (fgetc(xpm) != '{'); // ----- that's safe since imlib accepted ---
@@ -191,7 +206,7 @@ YCursorPixmap::YCursorPixmap(char const *path):
                     fHotspotY = (y < 0 ? 0 : y);
                 } else if (tokens != 4)
                     warn(_("BUG? Malformed XPM header but Imlib "
-                           "was able to parse \"%s\""), path);
+                           "was able to parse \"%s\""), cs.c_str());
 
                 fclose(xpm);
                 return;
@@ -199,10 +214,10 @@ YCursorPixmap::YCursorPixmap(char const *path):
             default:
                 if (c == EOF)
                     warn(_("BUG? Unexpected end of XPM file but Imlib "
-                           "was able to parse \"%s\""), path);
+                           "was able to parse \"%s\""), cs.c_str());
                 else
                     warn(_("BUG? Unexpected characted but Imlib "
-                           "was able to parse \"%s\""), path);
+                           "was able to parse \"%s\""), cs.c_str());
 
                 fclose(xpm);
                 return;
@@ -211,9 +226,19 @@ YCursorPixmap::YCursorPixmap(char const *path):
 }
 #endif
 
+#ifdef CONFIG_GDK_PIXBUF_XLIB
+YCursorPixmap::YCursorPixmap(upath /*path*/):
+    fPixmap(None), fMask(None),
+    fHotspotX(0), fHotspotY(0)
+{
+}
+#endif
+
 YCursorPixmap::~YCursorPixmap() {
-    XFreePixmap(xapp->display(), fPixmap);
-    XFreePixmap(xapp->display(), fMask);
+    if (fPixmap != None)
+        XFreePixmap(xapp->display(), fPixmap);
+    if (fMask != None)
+        XFreePixmap(xapp->display(), fMask);
 
 #ifdef CONFIG_XPM 
     XpmFreeAttributes(&fAttributes);
@@ -232,11 +257,16 @@ YCursor::~YCursor() {
 }
 
 #ifndef LITE
-void YCursor::load(char const *path) {
+
+static Pixmap createMask(int w, int h) {
+    return XCreatePixmap(xapp->display(), desktop->handle(), w, h, 1);
+}
+
+void YCursor::load(upath path) {
     YCursorPixmap pixmap(path);
     
     if (pixmap.isValid()) { // ============ convert coloured pixmap into a bilevel one ===
-        Pixmap bilevel(YPixmap::createMask(pixmap.width(), pixmap.height()));
+        Pixmap bilevel(createMask(pixmap.width(), pixmap.height()));
 
         // -------------------------- figure out which plane we have to copy ---
         unsigned long pmask(1 << (xapp->depth() - 1));
@@ -276,21 +306,21 @@ void YCursor::load(char const *path) {
 #endif
 
 #ifndef LITE
-void YCursor::load(char const *name, unsigned int fallback) {
+void YCursor::load(upath name, unsigned int fallback) {
 #else
-void YCursor::load(char const */*name*/, unsigned int fallback) {
+void YCursor::load(upath /*name*/, unsigned int fallback) {
 #endif
     if(fCursor && fOwned)
         XFreeCursor(xapp->display(), fCursor);
 
 #ifndef LITE
-    static char const *cursors = "cursors/";
-    YResourcePaths paths(cursors);
+    char const *cursors = "cursors/";
+    ref<YResourcePaths> paths = YResourcePaths::subdirs(cursors);
 
-    for (YPathElement const * pe(paths); pe->root && fCursor == None; pe++) {
-        char *path(pe->joinPath(cursors, name));
-        if (isreg(path)) load(path);
-        delete path;
+    for (int i = 0; i < paths->getCount(); i++) {
+        upath path = paths->getPath(i)->joinPath(cursors, name);
+        if (path.fileExists())
+            load(path.path());
     }
 
     if (fCursor == None)
