@@ -19,12 +19,13 @@ public:
     typedef XftChar8 char_t;
 #endif    
 
-    YXftFont(char const * name, bool xlfd);
+    YXftFont(ustring name, bool xlfd, bool antialias);
     virtual ~YXftFont();
 
     virtual bool valid() const { return (fFontCount > 0); }
     virtual int descent() const { return fDescent; }
     virtual int ascent() const { return fAscent; }
+    virtual int textWidth(const ustring &s) const;
     virtual int textWidth(char const * str, int len) const;
 
     virtual int textWidth(string_t const & str) const;
@@ -84,40 +85,53 @@ public:
 
 /******************************************************************************/
 
-YXftFont::YXftFont(const char *name, bool use_xlfd):
-    fFontCount(strtoken(name, ",")), fAscent(0), fDescent(0)
+YXftFont::YXftFont(ustring name, bool use_xlfd, bool /*antialias*/):
+    fFontCount(0), fAscent(0), fDescent(0)
 {
+    fFontCount = 0;
+    ustring s(null), r(null);
+
+    for (s = name; s.splitall(',', &s, &r); s = r) {
+        fFontCount++;
+    }
+
     XftFont ** fptr(fFonts = new XftFont* [fFontCount]);
 
-    for (char const *s(name); '\0' != *s; s = strnxt(s, ",")) {
+
+    for (s = name; s.splitall(',', &s, &r); s = r) {
+
+
+//    for (char const *s(name); '\0' != *s; s = strnxt(s, ",")) {
         XftFont *& font(*fptr);
 
-        char * fname(newstr(s + strspn(s, " \t\r\n"), ","));
-        char * endptr(fname + strlen(fname) - 1);
-        while (endptr > fname && strchr(" \t\r\n", *endptr)) --endptr;
-        endptr[1] = '\0';
+        ustring fname = s.trim();
+        //char * fname(newstr(s + strspn(s, " \t\r\n"), ","));
+        //char * endptr(fname + strlen(fname) - 1);
+        //while (endptr > fname && strchr(" \t\r\n", *endptr)) --endptr;
+        //endptr[1] = '\0';
 
-        if (use_xlfd)
-            font = XftFontOpenXlfd(xapp->display(), xapp->screen(), fname);
-        else
-            font = XftFontOpenName(xapp->display(), xapp->screen(), fname);
+        cstring cs(fname);
+        if (use_xlfd) {
+            font = XftFontOpenXlfd(xapp->display(), xapp->screen(), cs.c_str());
+        } else {
+            font = XftFontOpenName(xapp->display(), xapp->screen(), cs.c_str());
+        }
 
         if (NULL != font) {
             fAscent = max(fAscent, (unsigned) max(0, font->ascent));
             fDescent = max(fDescent, (unsigned) max(0, font->descent));
             ++fptr;
         } else {
-            warn(_("Could not load font \"%s\"."), fname);
+            warn(_("Could not load font \"%s\"."), cs.c_str());
             --fFontCount;
         }
-        delete[] fname;
     }
 
     if (0 == fFontCount) {
-        msg("xft: fallback from '%s'", name);
+        msg("xft: fallback from '%s'", cstring(name).c_str());
         XftFont *sans =
             XftFontOpen(xapp->display(), xapp->screen(),
-                        XFT_FAMILY, XftTypeString, "sans-serif,Bitstream Vera Serif",
+                        XFT_FAMILY, XftTypeString, "sans-serif",
                         XFT_PIXEL_SIZE, XftTypeInteger, 12,
                         NULL);
 
@@ -131,7 +145,7 @@ YXftFont::YXftFont(const char *name, bool use_xlfd):
             fAscent = sans->ascent;
             fDescent = sans->descent;
         } else
-            warn(_("Loading of fallback font \"%s\" failed."), "sans-serif,Bitstream Vera Serif");
+            warn(_("Loading of fallback font \"%s\" failed."), "sans-serif");
     }
 }
 
@@ -143,6 +157,11 @@ YXftFont::~YXftFont() {
     delete[] fFonts;
 }
 
+int YXftFont::textWidth(const ustring &s) const {
+    cstring cs(s);
+    return textWidth(cs.c_str(), cs.c_str_len());
+}
+
 int YXftFont::textWidth(string_t const & text) const {
     char_t * str((char_t *) text.data());
     size_t len(text.length());
@@ -264,22 +283,22 @@ YXftFont::TextPart * YXftFont::partitions(char_t * str, size_t len,
     return parts;
 }
 
-ref<YFont> getXftFontXlfd(const char *name) {
-    ref<YFont> font(new YXftFont(name, true));
+ref<YFont> getXftFontXlfd(ustring name, bool antialias) {
+    ref<YFont> font(new YXftFont(name, true, antialias));
     if (font == null || !font->valid()) {
-        msg("failed to load font '%s', trying fallback", name);
-        font.init(new YXftFont("sans-serif,Bitstream Vera Serif:size=12", false));
+        msg("failed to load font '%s', trying fallback", cstring(name).c_str());
+        font.init(new YXftFont("sans-serif:size=12", false, antialias));
         if (font == null || !font->valid())
             msg("Could not load fallback Xft font.");
     }
     return font;
 }
 
-ref<YFont> getXftFont(const char *name) {
-    ref<YFont>font(new YXftFont(name, false));
+ref<YFont> getXftFont(ustring name, bool antialias) {
+    ref<YFont>font(new YXftFont(name, false, antialias));
     if (font == null || !font->valid()) {
-        msg("failed to load font '%s', trying fallback", name);
-        font.init(new YXftFont("sans-serif,Bitstream Vera Serif:size=12", false));
+        msg("failed to load font '%s', trying fallback", cstring(name).c_str());
+        font.init(new YXftFont("sans-serif:size=12", false, antialias));
         if (font == null || !font->valid())
             msg("Could not load fallback Xft font.");
     }
