@@ -20,17 +20,23 @@
 
 extern ref<YFont> menuFont;
 
-YMenuItem::YMenuItem(const char *name, int aHotCharPos, const char *param, 
+YMenuItem::YMenuItem(const ustring &name, int aHotCharPos, const ustring &param,
                      YAction *action, YMenu *submenu) :
-    fName(newstr(name)), fParam(newstr(param)), fAction(action),
+    fName(name), fParam(param), fAction(action),
     fHotCharPos(aHotCharPos), fSubmenu(submenu), fIcon(null),
     fChecked(false), fEnabled(true) {
     
-    if (fName && (fHotCharPos == -2 || fHotCharPos == -3)) {
+    if (fName != null && (fHotCharPos == -2 || fHotCharPos == -3)) {
+        int i = fName.indexOf('_');
+        if (i != -1) {
+            fHotCharPos = i;
+            fName = fName.remove(i, 1);
+#if 0
         char *hotChar = strchr(fName, '_');
         if (hotChar != NULL) {
             fHotCharPos = (hotChar - fName);
             memmove(hotChar, hotChar + 1, strlen(hotChar));
+#endif
         } else {
             if (fHotCharPos == -3)
                 fHotCharPos = 0;
@@ -39,17 +45,17 @@ YMenuItem::YMenuItem(const char *name, int aHotCharPos, const char *param,
         }
     }
     
-    if (!fName || fHotCharPos >= int(strlen(fName)) || fHotCharPos < -1)
+    if (fName == null || fHotCharPos >= fName.length() || fHotCharPos < -1)
         fHotCharPos = -1;
 }
 
-YMenuItem::YMenuItem(const char *name) :
-    fName(newstr(name)), fParam(NULL), fAction(NULL), fHotCharPos (-1),
+YMenuItem::YMenuItem(const ustring &name) :
+    fName(name), fParam(null), fAction(NULL), fHotCharPos (-1),
     fSubmenu(0), fIcon(null), fChecked(false), fEnabled(true) {
 }
 
 YMenuItem::YMenuItem():
-    fName(0), fParam(0), fAction(0), fHotCharPos(-1), 
+    fName(null), fParam(null), fAction(0), fHotCharPos(-1),
     fSubmenu(0), fIcon(null), fChecked(false), fEnabled(false) {
 }
 
@@ -57,15 +63,13 @@ YMenuItem::~YMenuItem() {
     if (fSubmenu && !fSubmenu->isShared())
         delete fSubmenu;
     fSubmenu = 0;
-    delete[] fName; fName = 0;
-    delete[] fParam; fParam = 0;
 }
 
 void YMenuItem::setChecked(bool c) {
     fChecked = c;
 }
 
-void YMenuItem::setIcon(ref<YIconImage> icon) {
+void YMenuItem::setIcon(ref<YIcon> icon) {
     fIcon = icon;
 }
 
@@ -77,12 +81,14 @@ void YMenuItem::actionPerformed(YActionListener *listener, YAction *action, unsi
 int YMenuItem::queryHeight(int &top, int &bottom, int &pad) const {
     top = bottom = pad = 0;
 
-    if (getName() || getSubmenu()) {
+    if (getName() != null || getSubmenu()) {
         int fontHeight = max(16, menuFont->height() + 1);
         int ih = fontHeight;
 
-        if (getIcon() != null && getIcon()->height() > ih)
-            ih = getIcon()->height();
+#ifndef LITE
+        if (YIcon::smallSize() > ih)
+            ih = YIcon::smallSize();
+#endif
 
         if (wmLook == lookWarp4 || wmLook == lookWin95) {
             top = bottom = 0;
@@ -113,22 +119,20 @@ int YMenuItem::queryHeight(int &top, int &bottom, int &pad) const {
 }
 
 int YMenuItem::getIconWidth() const {
-    ref<YIconImage> icon = getIcon();
-    return icon != null ? icon->width() : 0;
+#ifdef LITE
+    return 0;
+#else
+    ref<YIcon> icon = getIcon();
+    return icon != null ? YIcon::smallSize(): 0;
+#endif
 }
 
 int YMenuItem::getNameWidth() const {
-    const char *name = getName();
-    return name ? menuFont->textWidth(name) : 0;
+    ustring name = getName();
+    return name != null ? menuFont->textWidth(name) : 0;
 }
 
 int YMenuItem::getParamWidth() const {
-    const char *param = getParam();
-    return  param ? menuFont->textWidth(param) : 0;
+    ustring param = getParam();
+    return  param != null ? menuFont->textWidth(param) : 0;
 }
-
-#ifndef LITE
-void YMenuItem::setIcon(YIcon *icon) {
-    setIcon(icon->getScaledIcon(menuIconSize));
-}
-#endif
