@@ -3,6 +3,7 @@
 
 #include "ypaint.h"
 #include "ypixbuf.h"
+#include "yicon.h"
 
 class YMenu;
 class YAction;
@@ -10,25 +11,25 @@ class YActionListener;
 
 class YMenuItem {
 public:
-    YMenuItem(const char *name, int hotCharPos, const char *param, YAction *action, YMenu *submenu);
-    YMenuItem(const char *name);
+    YMenuItem(const ustring &name, int hotCharPos, const ustring &param, YAction *action, YMenu *submenu);
+    YMenuItem(const ustring &name);
     YMenuItem();
     virtual ~YMenuItem();
 
-    char *getName() const { return fName; }
-    const char *getParam() const { return fParam; }
+    ustring getName() const { return fName; }
+    ustring getParam() const { return fParam; }
     YAction *getAction() const { return fAction; }
     YMenu *getSubmenu() const { return fSubmenu; }
 
     int getHotChar() const { 
-        return (fName && fHotCharPos >= 0) ? fName[fHotCharPos] : -1;
+        return (fName != null && fHotCharPos >= 0) ? fName.charAt(fHotCharPos) : -1;
     }
 
     int getHotCharPos() const { 
         return fHotCharPos;
     }
 
-    ref<YIconImage> getIcon() const { return fIcon; }
+    ref<YIcon> getIcon() const { return fIcon; }
     void setChecked(bool c);
     int isChecked() const { return fChecked; }
     int isEnabled() const { return fEnabled; }
@@ -43,20 +44,18 @@ public:
     int getNameWidth() const;
     int getParamWidth() const;
 
-    bool isSeparator() { return !getName() && !getSubmenu(); }
+    bool isSeparator() { return getName() == null && getSubmenu() == 0; }
     
-    void setIcon(YIcon *icon);
+    void setIcon(ref<YIcon> icon);
 private:
-    char *fName;
-    char *fParam;
+    ustring fName;
+    ustring fParam;
     YAction *fAction;
     int fHotCharPos;
     YMenu *fSubmenu;
-    ref<YIconImage> fIcon;
+    ref<YIcon> fIcon;
     bool fChecked;
     bool fEnabled;
-
-    void setIcon(ref<YIconImage> icon);
 };
 
 #endif
