@@ -3,7 +3,12 @@
 
 #include "base.h"
 #include "ref.h"
+#include "ypixmap.h"
+#include "yimage.h"
+#include "mstring.h"
+#if 0
 #include "ypixbuf.h"
+#endif
 
 #include <X11/Xlib.h>
 
@@ -36,7 +41,6 @@
 #endif // CONFIG_GRADIENTS -----------------------------------------------------
 
 class YWindow;
-class YPixbuf;
 class YIcon;
 
 #ifdef SHAPE
@@ -47,6 +51,8 @@ enum YDirection {
     Up, Left, Down, Right
 };
 
+class YImage;
+
 /******************************************************************************/
 /******************************************************************************/
 
@@ -96,7 +102,7 @@ struct YDimension {
 
 class YFont: public virtual refcounted {
 public:
-    static ref<YFont> getFont(char const *name, const char *xftFont, bool antialias = true);
+    static ref<YFont> getFont(ustring name, ustring xftFont, bool antialias = true);
 
     virtual ~YFont() {}
 
@@ -104,6 +110,7 @@ public:
     virtual int height() const { return ascent() + descent(); }
     virtual int descent() const = 0;
     virtual int ascent() const = 0;
+    virtual int textWidth(const ustring &s) const = 0;
     virtual int textWidth(char const * str, int len) const = 0;
 
     virtual void drawGlyphs(class Graphics & graphics, int x, int y, 
@@ -112,61 +119,16 @@ public:
     int textWidth(char const * str) const;
     int multilineTabPos(char const * str) const;
     YDimension multilineAlloc(char const * str) const;
-
-    static char * getNameElement(char const * pattern, unsigned const element);
+    YDimension multilineAlloc(const ustring &str) const;
 };
 
 /******************************************************************************/
 /******************************************************************************/
 
-class YPixmap: public virtual refcounted {
-public:
-//    YPixmap(YPixmap const &pixmap);
-#ifdef CONFIG_ANTIALIASING
-    YPixmap(YPixbuf & pixbuf);
-#endif
-
-    YPixmap(char const * fileName);
-#if 0
-    YPixmap(char const * fileName, int w, int h);
-#endif
-    YPixmap(int w, int h, bool mask = false);
-    YPixmap(Pixmap pixmap, Pixmap mask, int w, int h);
-#ifdef CONFIG_IMLIB
-    YPixmap(Pixmap pixmap, Pixmap mask, int w, int h, int wScaled, int hScaled);
-    void scaleImage(Pixmap pixmap, Pixmap mask, int x, int y, int w, int h, int nw, int nh);
-#endif
-    ~YPixmap();
-
-private:
-    YPixmap(const ref<YPixmap> &pixmap, int newWidth, int newHeight);
-public:
-    static ref<YPixmap> scale(ref<YPixmap> source, int const width, int const height);
-
-    Pixmap pixmap() const { return fPixmap; }
-    Pixmap mask() const { return fMask; }
-    int width() const { return fWidth; }
-    int height() const { return fHeight; }
-    
-    bool valid() const { return (fPixmap != None); }
-
-    void replicate(bool horiz, bool copyMask);
-
-    static Pixmap createPixmap(int w, int h);
-    static Pixmap createPixmap(int w, int h, int depth);
-    static Pixmap createMask(int w, int h);
-
-private:
-    Pixmap fPixmap;
-    Pixmap fMask;
-    unsigned int fWidth, fHeight;
-    bool fOwned;
-};
-
 struct YSurface {
 #ifdef CONFIG_GRADIENTS
     YSurface(class YColor * color, ref<YPixmap> pixmap,
-             ref<YPixbuf> gradient):
+             ref<YImage> gradient):
     color(color), pixmap(pixmap), gradient(gradient) {}
 #else
     YSurface(class YColor * color, ref<YPixmap> pixmap):
@@ -176,16 +138,10 @@ struct YSurface {
     class YColor * color;
     ref<YPixmap> pixmap;
 #ifdef CONFIG_GRADIENTS
-    ref<YPixbuf> gradient;
+    ref<YImage> gradient;
 #endif
 };
 
-#ifdef CONFIG_ANTIALIASING
-typedef YPixbuf YIconImage;
-#else    
-typedef YPixmap YIconImage;
-#endif
-
 class Graphics {
 public:
     Graphics(YWindow & window, unsigned long vmask, XGCValues * gcv);
@@ -199,23 +155,27 @@ public:
                   const int dx, const int dy);
     void copyDrawable(const Drawable d, const int x, const int y, 
                       const int w, const int h, const int dx, const int dy);
+#if 0
     void copyImage(XImage * im, const int x, const int y, 
                    const int w, const int h, const int dx, const int dy);
     void copyImage(XImage * im, const int x, const int y) {
         copyImage(im, 0, 0, im->width, im->height, x, y);
     }
+#endif
     void copyPixmap(const ref<YPixmap> &p, const int x, const int y,
-                    const int w, const int h, const int dx, const int dy)
+                     const int w, const int h, const int dx, const int dy)
     {
         if (p != null)
             copyDrawable(p->pixmap(), x, y, w, h, dx, dy);
     }
+#if 0
 #ifdef CONFIG_ANTIALIASING
     void copyPixbuf(class YPixbuf & pixbuf, const int x, const int y,
                     const int w, const int h, const int dx, const int dy,
                     bool useAlpha = true);
     void copyAlphaMask(class YPixbuf & pixbuf, const int x, const int y,
                        const int w, const int h, const int dx, const int dy);
+#endif
 #endif
 
     void drawPoint(int x, int y);
@@ -227,16 +187,23 @@ public:
     void drawArc(int x, int y, int width, int height, int a1, int a2);
     void drawArrow(YDirection direction, int x, int y, int size, bool pressed = false);
 
+    void drawChars(const ustring &s, int x, int y);
     void drawChars(char const * data, int offset, int len, int x, int y);
     void drawCharUnderline(int x, int y, char const * str, int charPos);
 
+    void drawCharUnderline(int x, int y, const ustring &str, int charPos);
+
     void drawString(int x, int y, char const * str);
     void drawStringEllipsis(int x, int y, char const * str, int maxWidth);
+    void drawStringEllipsis(int x, int y, const ustring &str, int maxWidth);
     void drawStringMultiline(int x, int y, char const * str);
+    void drawStringMultiline(int x, int y, const ustring &str);
 
-    void drawImage(const ref<YIconImage> &img, int const x, int const y);
-    void drawPixmap(const ref<YPixmap> &pix, int const x, int const y);
-    void drawMask(const ref<YPixmap> &pix, int const x, int const y);
+    void drawPixmap(ref<YPixmap> pix, int const x, int const y);
+    void drawImage(ref<YImage> pix, int const x, int const y);
+    void drawImage(ref<YImage> pix, int const x, int const y, int w, int h, int dx, int dy);
+    void compositeImage(ref<YImage> pix, int const x, int const y, int w, int h, int dx, int dy);
+    void drawMask(ref<YPixmap> pix, int const x, int const y);
     void drawClippedPixmap(Pixmap pix, Pixmap clip,
                            int x, int y, int w, int h, int toX, int toY);
     void fillRect(int x, int y, int width, int height);
@@ -252,7 +219,7 @@ public:
     void setLineWidth(int width);
     void setPenStyle(bool dotLine = false); ///!!!hack
     void setFunction(int function = GXcopy);
-    
+
     void draw3DRect(int x, int y, int w, int h, bool raised);
     void drawBorderW(int x, int y, int w, int h, bool raised);
     void drawBorderM(int x, int y, int w, int h, bool raised);
@@ -271,20 +238,20 @@ public:
     }
 
 #ifdef CONFIG_GRADIENTS
-    void drawGradient(const ref<YPixbuf> &pixbuf,
+    void drawGradient(ref<YImage> gradient,
                       int const x, int const y, const int w, const int h,
                       int const gx, int const gy, const int gw, const int gh);
-    void drawGradient(const ref<YPixbuf> &pixbuf,
+    void drawGradient(ref<YImage> gradient,
                       int const x, int const y, const int w, const int h) {
-        drawGradient(pixbuf, x, y, w, h, 0, 0, w, h);
+        drawGradient(gradient, x, y, w, h, 0, 0, w, h);
     }
 #endif
 
-    void repHorz(const ref<YPixmap> &p, int x, int y, int w) {
+    void repHorz(ref<YPixmap> p, int x, int y, int w) {
         if (p != null)
             repHorz(p->pixmap(), p->width(), p->height(), x, y, w);
     }
-    void repVert(const ref<YPixmap> &p, int x, int y, int h) {
+    void repVert(ref<YPixmap> p, int x, int y, int h) {
         if (p != null)
             repVert(p->pixmap(), p->width(), p->height(), x, y, h);
     }
@@ -301,6 +268,8 @@ public:
     int function() const;
     int xorigin() const { return xOrigin; }
     int yorigin() const { return yOrigin; }
+    int rwidth() const { return rWidth; }
+    int rheight() const { return rHeight; }
 
     void setClipRectangles(XRectangle *rect, int count);
     void setClipMask(Pixmap mask = None);
