@@ -13,6 +13,7 @@ XIV(bool, multiByte,                            true)
 #endif
 XIV(bool, modSuperIsCtrlAlt,                    true)
 XIV(bool, doubleBuffer,                         true)
+XIV(bool, xrrDisable,                           false)
 XIV(int, xineramaPrimaryScreen,                 0)
 XIV(int, MenuActivateDelay,                     40)
 XIV(int, SubmenuActivateDelay,                  300)
@@ -29,17 +30,13 @@ XIV(int, ToolTipTime,                           0)
 ///#warning "move this one back to WM"
 XIV(bool, grabRootWindow,                       true)
 
-#ifdef CONFIG_IMLIB
-XIV(bool, disableImlibCaches,                   true)
-#endif
 #ifdef CONFIG_XFREETYPE
 XIV(bool, haveXft,                              true)
 #endif
-XSV(const char *, iconPath,                     "/usr/share/icons:/usr/share/pixmaps")
-XSV(const char *, libDir,                       LIBDIR)
-XSV(const char *, configDir,                    CFGDIR)
+XSV(const char *, iconPath,                     0)
 #define CONFIG_DEFAULT_THEME "icedesert/default.theme"
 XSV(const char *, themeName,                    CONFIG_DEFAULT_THEME)
+XSV(const char *, xineramaPrimaryScreenName,    0)
 
 #define CONFIG_DEFAULT_LOOK lookNice
 
@@ -168,6 +165,6 @@ XIV(WMLook, wmLook,                             CONFIG_DEFAULT_LOOK)
 XSV(const char *, clrToolTip,                   "rgb:E0/E0/00")
 XSV(const char *, clrToolTipText,               "rgb:00/00/00")
 #endif
-XFV(const char *, toolTipFontName,              FONT(120), "sans-serif,Bitstream Vera Serif:size=12")
+XFV(const char *, toolTipFontName,              FONT(120), "sans-serif:size=12")
 
 #endif
